---
title: Introduction
---
**On December 17, 1903,** on a windy North Carolina beach for just shy of one hundred seconds, the Wright brothers demonstrated that a heavier-than-air, self-propelled vehicle could fly. #firstFlight(5) #US
The moment was electric and its importance widely understood.
Almost immediately, there was an explosion of interest in this newfound technology of manned flight, and a gaggle of innovators began to build upon it.

At the time the Wright brothers invented the airplane, American law held that a property owner presumptively owned not just the surface of his land, but all the land below, down to the center of the earth, and all the space above, to [“an indefinite extent, upwards.”][^4]
For many years, scholars had puzzled about how best to interpret the idea that rights in land ran to the heavens.
Did that mean that you owned the stars?
Could you prosecute geese for their willful and regular trespass?

Then came airplanes, and for the first time, this principle of American law—deep within the foundations of our tradition, and acknowledged by the most important legal thinkers of our past—mattered.
If my land reaches to the heavens, what happens when United flies over my field?
Do I have the right to banish it from my property?
Am I allowed to enter into an exclusive license with Delta Airlines?
Could we set up an auction to decide how much these rights are worth?

In 1945, these questions became a federal case.
When North Carolina farmers Thomas Lee and Tinie Causby started losing chickens because of low-flying military aircraft (the terrified chickens apparently flew into the barn walls and died), the Causbys filed a lawsuit saying that the government was trespassing on their land.
The airplanes, of course, never touched the surface of the Causbys' land.
But if, as Blackstone, Kent, and Coke had said, their land reached to “an indefinite extent, upwards,” then the government was trespassing on their property, and the Causbys wanted it to stop.

The Supreme Court agreed to hear the Causbys' case.
Congress had declared the airways public, but if one's property really extended to the heavens, then Congress's declaration could well have been an unconstitutional “taking” of property without compensation.
The Court acknowledged that “it is ancient doctrine that common law ownership of the land extended to the periphery of the universe.”
But Justice Douglas had no patience for ancient doctrine.
In a single paragraph, hundreds of years of property law were erased.
As he wrote for the Court,

> [The] doctrine has no place in the modern world.
The air is a public highway, as Congress has declared.
Were that not true, every transcontinental flight would subject the operator to countless trespass suits.
Common sense revolts at the idea.
To recognize such private claims to the airspace would clog these highways, seriously interfere with their control and development in the public interest, and transfer into private ownership that to which only the public has a just claim.[^5]

“Common sense revolts at the idea.”

This is how the law usually works.
Not often this abruptly or impatiently, but eventually, this is how it works.
It was Douglas's style not to dither.
Other justices would have blathered on for pages to reach the conclusion that Douglas holds in a single line: “Common sense revolts at the idea.”
But whether it takes pages or a few words, it is the special genius of a common law system, as ours is, that the law adjusts to the technologies of the time.
And as it adjusts, it changes.
Ideas that were as solid as rock in one age crumble in another.

Or at least, this is how things happen when there's no one powerful on the other side of the change.
The Causbys were just farmers.
And though there were no doubt many like them who were upset by the growing traffic in the air (though one hopes not many chickens flew themselves into walls), the Causbys of the world would find it very hard to unite and stop the idea, and the technology, that the Wright brothers had birthed.
The Wright brothers spat airplanes into the technological meme pool; the idea then spread like a virus in a chicken coop; farmers like the Causbys found themselves surrounded by “what seemed reasonable” given the technology that the Wrights had produced.
They could stand on their farms, dead chickens in hand, and shake their fists at these newfangled technologies all they wanted.
They could call their representatives or even file a lawsuit.
But in the end, the force of what seems “obvious” to everyone else—the power of “common sense”—would prevail.
Their “private interest” would not be allowed to defeat an obvious public gain.

**Edwin Howard Armstrong** is one of America's forgotten inventor geniuses.
He came to the great American inventor scene just after the titans Thomas Edison and Alexander Graham Bell.
But his work in the area of radio technology was perhaps the most important of any single inventor in the first fifty years of radio.
He was better educated than Michael Faraday, who as a bookbinder's apprentice had discovered electric induction in 1831\. But he had the same intuition about how the world of radio worked, and on at least three occasions, Armstrong invented profoundly important technologies that advanced our understanding of radio.

On the day after Christmas, 1933, four patents were issued to Armstrong for his most significant invention—FM radio.
Until then, consumer radio had been amplitude-modulated (AM) radio.
The theorists of the day had said that frequency-modulated (FM) radio could never work.
They were right about FM radio in a narrow band of spectrum.
But Armstrong discovered that frequency-modulated radio in a wide band of spectrum would deliver an astonishing fidelity of sound, with much less transmitter power and static.

On November 5, 1935, he demonstrated the technology at a meeting of the Institute of Radio Engineers at the Empire State Building in New York City.
He tuned his radio dial across a range of AM stations, until the radio locked on a broadcast that he had arranged from seventeen miles away.
The radio fell totally silent, as if dead, and then with a clarity no one else in that room had ever heard from an electrical device, it produced the sound of an announcer's voice: “This is amateur station W2AG at Yonkers, New York, operating on frequency modulation at two and a half meters.”

The audience was hearing something no one had thought possible:

> A glass of water was poured before the microphone in Yonkers; it sounded like a glass of water being poured…
A paper was crumpled and torn; it sounded like paper and not like a crackling forest fire…
Sousa marches were played from records and a piano solo and guitar number were performed…
The music was projected with a live-ness rarely if ever heard before from a radio “music box.”[^6]

As our own common sense tells us, Armstrong had discovered a vastly superior radio technology.
But at the time of his invention, Armstrong was working for RCA.
RCA was the dominant player in the then dominant AM radio market.
By 1935, there were a thousand radio stations across the United States, but the stations in large cities were all owned by a handful of networks.

RCA's president, David Sarnoff, a friend of Armstrong's, was eager that Armstrong discover a way to remove static from AM radio.
So Sarnoff was quite excited when Armstrong told him he had a device that removed static from “radio.”
But when Armstrong demonstrated his invention, Sarnoff was not pleased.

> I thought Armstrong would invent some kind of a filter to remove static from our AM radio.
I didn't think he'd start a revolution—start up a whole damn new industry to compete with RCA.[^7]

Armstrong's invention threatened RCA's AM empire, so the company launched a campaign to smother FM radio.
While FM may have been a superior technology, Sarnoff was a superior tactician.
As one author described,

> The forces for FM, largely engineering, could not overcome the weight of strategy devised by the sales, patent, and legal offices to subdue this threat to corporate position.
For FM, if allowed to develop unrestrained, posed … a complete reordering of radio power … and the eventual overthrow of the carefully restricted AM system on which RCA had grown to power.[^8]

RCA at first kept the technology in house, insisting that further tests were needed.
When, after two years of testing, Armstrong grew impatient, RCA began to use its power with the government to stall FM radio's deployment generally.
In 1936, RCA hired the former head of the FCC and assigned him the task of assuring that the FCC assign spectrum in a way that would castrate FM—principally by moving FM radio to a different band of spectrum.
At first, these efforts failed.
But when Armstrong and the nation were distracted by World War II, RCA's work began to be more successful.
Soon after the war ended, the FCC announced a set of policies that would have one clear effect: FM radio would be crippled.
As Lawrence Lessing described it,

> The series of body blows that FM radio received right after the war, in a series of rulings manipulated through the FCC by the big radio interests, were almost incredible in their force and deviousness.[^9]

To make room in the spectrum for RCA's latest gamble, television, FM radio users were to be moved to a totally new spectrum band.
The power of FM radio stations was also cut, meaning FM could no longer be used to beam programs from one part of the country to another.
(This change was strongly supported by AT&T, because the loss of FM relaying stations would mean radio stations would have to buy wired links from AT&T.)
The spread of FM radio was thus choked, at least temporarily.

Armstrong resisted RCA's efforts.
In response, RCA resisted Armstrong's patents.
After incorporating FM technology into the emerging standard for television, RCA declared the patents invalid—baselessly, and almost fifteen years after they were issued.
It thus refused to pay him royalties.
For six years, Armstrong fought an expensive war of litigation to defend the patents.
Finally, just as the patents expired, RCA offered a settlement so low that it would not even cover Armstrong's lawyers' fees.
Defeated, broken, and now broke, in 1954 Armstrong wrote a short note to his wife and then stepped out of a thirteenth-story window to his death.

This is how the law sometimes works.
Not often this tragically, and rarely with heroic drama, but sometimes, this is how it works.
From the beginning, government and government agencies have been subject to capture.
They are more likely captured when a powerful interest is threatened by either a legal or technical change.
That powerful interest too often exerts its influence within the government to get the government to protect it. The rhetoric of this protection is of course always public spirited; the reality is something different.
Ideas that were as solid as rock in one age, but that, left to themselves, would crumble in another, are sustained through this subtle corruption of our political process.
RCA had what the Causbys did not: the power to stifle the effect of technological change.

**There's no** single inventor of the Internet.
Nor is there any good date upon which to mark its birth.
Yet in a very short time, the Internet has become part of ordinary American life.
According to the Pew Internet and American Life Project, 58 percent of Americans had access to the Internet in 2002, up from 49 percent two years before.[^10]
That number could well exceed two thirds of the nation by the end of 2004.

As the Internet has been integrated into ordinary life, it has changed things.
Some of these changes are technical—the Internet has made communication faster, it has lowered the cost of gathering data, and so on. These technical changes are not the focus of this book.
They are important.
They are not well understood.
But they are the sort of thing that would simply go away if we all just switched the Internet off.
They don't affect people who don't use the Internet, or at least they don't affect them directly.
They are the proper subject of a book about the Internet.
But this is not a book about the Internet.

Instead, this book is about an effect of the Internet beyond the Internet itself: an effect upon how culture is made.
My claim is that the Internet has induced an important and unrecognized change in that process.
That change will radically transform a tradition that is as old as the Republic itself.
Most, if they recognized this change, would reject it. Yet most don't even see the change that the Internet has introduced.

We can glimpse a sense of this change by distinguishing between commercial and noncommercial culture, and by mapping the law's regulation of each.
By “commercial culture” I mean that part of our culture that is produced and sold or produced to be sold.
By “noncommercial culture” I mean all the rest.
When old men sat around parks or on street corners telling stories that kids and others consumed, that was noncommercial culture.
When Noah Webster published his “Reader,” or Joel Barlow his poetry, that was commercial culture.

At the beginning of our history, and for just about the whole of our tradition, noncommercial culture was essentially unregulated.
Of course, if your stories were lewd, or if your song disturbed the peace, then the law might intervene.
But the law was never directly concerned with the creation or spread of this form of culture, and it left this culture “free.”
The ordinary ways in which ordinary individuals shared and transformed their culture—telling stories, reenacting scenes from plays or TV, participating in fan clubs, sharing music, making tapes—were left alone by the law.

The focus of the law was on commercial creativity.
At first slightly, then quite extensively, the law protected the incentives of creators by granting them exclusive rights to their creative work, so that they could sell those exclusive rights in a commercial marketplace.[^11]
This is also, of course, an important part of creativity and culture, and it has become an increasingly important part in America.
But in no sense was it dominant within our tradition.
It was instead just one part, a controlled part, balanced with the free.

This rough divide between the free and the controlled has now been erased.[^12]
The Internet has set the stage for this erasure and, pushed by big media, the law has now affected it. For the first time in our tradition, the ordinary ways in which individuals create and share culture fall within the reach of the regulation of the law, which has expanded to draw within its control a vast amount of culture and creativity that it never reached before.
The technology that preserved the balance of our history—between uses of our culture that were free and uses of our culture that were only upon permission—has been undone.
The consequence is that we are less and less a free culture, more and more a permission culture.

This change gets justified as necessary to protect commercial creativity.
And indeed, protectionism is precisely its motivation.
But the protectionism that justifies the changes that I will describe below is not the limited and balanced sort that has defined the law in the past.
This is not a protectionism to protect artists.
It is instead a protectionism to protect certain forms of business.
Corporations threatened by the potential of the Internet to change the way both commercial and noncommercial culture are made and shared have united to induce lawmakers to use the law to protect them.
It is the story of RCA and Armstrong; it is the dream of the Causbys.

For the Internet has unleashed an extraordinary possibility for many to participate in the process of building and cultivating a culture that reaches far beyond local boundaries.
That power has changed the marketplace for making and cultivating culture generally, and that change in turn threatens established content industries.
The Internet is thus to the industries that built and distributed content in the twentieth century what FM radio was to AM radio, or what the truck was to the railroad industry of the nineteenth century: the beginning of the end, or at least a substantial transformation.
Digital technologies, tied to the Internet, could produce a vastly more competitive and vibrant market for building and cultivating culture; that market could include a much wider and more diverse range of creators; those creators could produce and distribute a much more vibrant range of creativity; and depending upon a few important factors, those creators could earn more on average from this system than creators do today—all so long as the RCAs of our day don't use the law to protect themselves against this competition.

Yet, as I argue in the pages that follow, that is precisely what is happening in our culture today.
These modern-day equivalents of the early twentieth-century radio or nineteenth-century railroads are using their power to get the law to protect them against this new, more efficient, more vibrant technology for building culture.
They are succeeding in their plan to remake the Internet before the Internet remakes them.

It doesn't seem this way to many.
The battles over copyright and the Internet seem remote to most.
To the few who follow them, they seem mainly about a much simpler brace of questions—whether “piracy” will be permitted, and whether “property” will be protected.
The “war” that has been waged against the technologies of the Internet—what Motion Picture Association of America (MPAA) president Jack Valenti calls his “own terrorist war”[^13]—has been framed as a battle about the rule of law and respect for property.
To know which side to take in this war, most think that we need only decide whether we're for property or against it.

If those really were the choices, then I would be with Jack Valenti and the content industry.
I, too, am a believer in property, and especially in the importance of what Mr. Valenti nicely calls “creative property.”
I believe that “piracy” is wrong, and that the law, properly tuned, should punish “piracy,” whether on or off the Internet.

But those simple beliefs mask a much more fundamental question and a much more dramatic change.
My fear is that unless we come to see this change, the war to rid the world of Internet “pirates” will also rid our culture of values that have been integral to our tradition from the start.

These values built a tradition that, for at least the first 180 years of our Republic, guaranteed creators the right to build freely upon their past, and protected creators and innovators from either state or private control.
The First Amendment protected creators against state control.
And as Professor Neil Netanel powerfully argues,[^14] copyright law, properly balanced, protected creators against private control.
Our tradition was thus neither Soviet nor the tradition of patrons.
It instead carved out a wide berth within which creators could cultivate and extend our culture.

Yet the law's response to the Internet, when tied to changes in the technology of the Internet itself, has massively increased the effective regulation of creativity in America.
To build upon or critique the culture around us one must ask, Oliver Twist-like, for permission first.
Permission is, of course, often granted—but it is not often granted to the critical or the independent.
We have built a kind of cultural nobility; those within the noble class live easily; those outside it don't. But it is nobility of any form that is alien to our tradition.

The story that follows is about this war.
Is it not about the “centrality of technology” to ordinary life.
I don't believe in gods, digital or otherwise.
Nor is it an effort to demonize any individual or group, for neither do I believe in a devil, corporate or otherwise.
It is not a morality tale.
Nor is it a call to jihad against an industry.

It is instead an effort to understand a hopelessly destructive war inspired by the technologies of the Internet but reaching far beyond its code.
And by understanding this battle, it is an effort to map peace.
There is no good reason for the current struggle around Internet technologies to continue.
There will be great harm to our tradition and culture if it is allowed to continue unchecked.
We must come to understand the source of this war.
We must resolve it soon.

**Like the Causbys'** battle, this war is, in part, about “property.”
The property of this war is not as tangible as the Causbys', and no innocent chicken has yet to lose its life.
Yet the ideas surrounding this “property” are as obvious to most as the Causbys' claim about the sacredness of their farm was to them.
We are the Causbys.
Most of us take for granted the extraordinarily powerful claims that the owners of “intellectual property” now assert.
Most of us, like the Causbys, treat these claims as obvious.
And hence we, like the Causbys, object when a new technology interferes with this property.
It is as plain to us as it was to them that the new technologies of the Internet are “trespassing” upon legitimate claims of “property.”
It is as plain to us as it was to them that the law should intervene to stop this trespass.

And thus, when geeks and technologists defend their Armstrong or Wright brothers technology, most of us are simply unsympathetic.
Common sense does not revolt.
Unlike in the case of the unlucky Causbys, common sense is on the side of the property owners in this war.
Unlike the lucky Wright brothers, the Internet has not inspired a revolution on its side.

My hope is to push this common sense along.
I have become increasingly amazed by the power of this idea of intellectual property and, more importantly, its power to disable critical thought by policy makers and citizens.
There has never been a time in our history when more of our “culture” was as “owned” as it is now.
And yet there has never been a time when the concentration of power to control the _uses_ of culture has been as unquestioningly accepted as it is now.

The puzzle is, Why?

Is it because we have come to understand a truth about the value and importance of absolute property over ideas and culture?
Is it because we have discovered that our tradition of rejecting such an absolute claim was wrong?

Or is it because the idea of absolute property over ideas and culture benefits the RCAs of our time and fits our own unreflective intuitions?

Is the radical shift away from our tradition of free culture an instance of America correcting a mistake from its past, as we did after a bloody war with slavery, and as we are slowly doing with inequality?
Or is the radical shift away from our tradition of free culture yet another example of a political system captured by a few powerful special interests?

Does common sense lead to the extremes on this question because common sense actually believes in these extremes?
Or does common sense stand silent in the face of these extremes because, as with Armstrong versus RCA, the more powerful side has ensured that it has the more powerful view?

I don't mean to be mysterious.
My own views are resolved.
I believe it was right for common sense to revolt against the extremism of the Causbys.
I believe it would be right for common sense to revolt against the extreme claims made today on behalf of “intellectual property.”
What the law demands today is increasingly as silly as a sheriff arresting an airplane for trespass.
But the consequences of this silliness will be much more profound.

***

**The struggle** that rages just now centers on two ideas: “piracy” and “property.”
My aim in this book's next two parts is to explore these two ideas.

My method is not the usual method of an academic.
I don't want to plunge you into a complex argument, buttressed with references to obscure French theorists—however natural that is for the weird sort we academics have become.
Instead I begin in each part with a collection of stories that set a context within which these apparently simple ideas can be more fully understood.

The two sections set up the core claim of this book: that while the Internet has indeed produced something fantastic and new, our government, pushed by big media to respond to this “something new,” is destroying something very old.
Rather than understanding the changes the Internet might permit, and rather than taking time to let “common sense” resolve how best to respond, we are allowing those most threatened by the changes to use their power to change the law—and more importantly, to use their power to change something fundamental about who we have always been.

We allow this, I believe, not because it is right, and not because most of us really believe in these changes.
We allow it because the interests most threatened are among the most powerful players in our depressingly compromised process of making law.
This book is the story of one more consequence of this form of corruption—a consequence to which most of us remain oblivious.  


[^4]: St. George Tucker, *Blackstone's Commentaries* 3 (South Hackensack, N.J.: Rothman Reprints, 1969), 18.

[^5]: United States v. Causby, U.S. 328 (1946): 256, 261.
	The Court did find that there could be a “taking” if the government's use of its land effectively destroyed the value of the Causbys' land.
	This example was suggested to me by Keith Aoki's wonderful piece, “(Intellectual) Property and Sovereignty: Notes  Toward a Cultural Geography of Authorship,”
	*Stanford Law Review* 48 (1996): 1293, 1333.
	See also Paul Goldstein, *Real Property* (Mineola, N.Y.: Foundation Press, 1984), 1112-13.

[^6]: Lawrence Lessing, *Man of High Fidelity: Edwin Howard Armstrong* (Philadelphia: J. B. Lipincott Company, 1956), 209\.

[^7]: See “Saints: The Heroes and Geniuses of the Electronic Era,” First Electronic Church of America, at <a href="http://www.webstationone.com/fecha" target="\_blank">www.webstationone.com/fecha</a>, available at link #1.

[^8]: Lessing, 226.

[^9]: Lessing, 256.

[^10]: Amanda Lenhart, “The Ever-Shifting Internet Population: A New Look at Internet Access and the Digital Divide,” Pew Internet and American Life Project, 15 April 2003: 6, available at link #2.

[^11]: This is not the only purpose of copyright, though it is the overwhelmingly primary purpose of the copyright established in the federal constitution.
	State copyright law historically protected not just the commercial interest in publication, but also a privacy interest.
	By granting authors the exclusive right to first publication, state copyright law gave authors the power to control the spread of facts about them.
	See Samuel D. Warren and Louis D. Brandeis, “The Right to Privacy,” *Harvard Law Review* 4 (1890): 193, 198-200.

[^12]: See Jessica Litman, *Digital Copyright* (New York: Prometheus Books, 2001), ch. 13.

[^13]: Amy Harmon, “Black Hawk Download: Moving Beyond Music, Pirates Use New Tools to Turn the Net into an Illicit Video Club,” *New York Times*, 17 January 2002.

[^14]: Neil W. Netanel, “Copyright and a Democratic Civil Society,” *Yale Law Journal* 106 (1996): 283.

