---
title: “Piracy”
---

**Since the inception** of the law regulating creative property, there has been a war against “piracy.”
The precise contours of this concept, “piracy,” are hard to sketch, but the animating injustice is easy to capture.
As Lord Mansfield wrote in a case that extended the reach of English copyright law to include sheet music,

> A person may use the copy by playing it, but he has no right to rob the author of the profit, by multiplying copies and disposing of them for his own use.[^15]

Today we are in the middle of another “war” against “piracy.”
The Internet has provoked this war.
The Internet makes possible the efficient spread of content.
Peer-to-peer (p2p) file sharing is among the most efficient of the efficient technologies the Internet enables.
Using distributed intelligence, p2p systems facilitate the easy spread of content in a way unimagined a generation ago.

This efficiency does not respect the traditional lines of copyright.
The network doesn't discriminate between the sharing of copyrighted and uncopyrighted content.
Thus has there been a vast amount of sharing of copyrighted content.
That sharing in turn has excited the war, as copyright owners fear the sharing will “rob the author of the profit.”

The warriors have turned to the courts, to the legislatures, and increasingly to technology to defend their “property” against this “piracy.”
A generation of Americans, the warriors warn, is being raised to believe that “property” should be “free.”
Forget tattoos, never mind body piercing—our kids are becoming _thieves_!

There's no doubt that “piracy” is wrong, and that pirates should be punished.
But before we summon the executioners, we should put this notion of “piracy” in some context.
For as the concept is increasingly used, at its core is an extraordinary idea that is almost certainly wrong.

The idea goes something like this:

> Creative work has value; whenever I use, or take, or build upon the creative work of others, I am taking from them something of value.
Whenever I take something of value from someone else, I should have their permission.
The taking of something of value from someone else without permission is wrong.
It is a form of piracy.

This view runs deep within the current debates.
It is what NYU law professor Rochelle Dreyfuss criticizes as the “if value, then right” theory of creative property[^16]—if there is value, then someone must have a right to that value.
It is the perspective that led a composers' rights organization, ASCAP, to sue the Girl Scouts for failing to pay for the songs that girls sang around Girl Scout campfires.[^17]
There was “value” (the songs) so there must have been a “right”—even against the Girl Scouts.

This idea is certainly a possible understanding of how creative property should work.
It might well be a possible design for a system of law protecting creative property.
But the “if value, then right” theory of creative property has never been America's theory of creative property.
It has never taken hold within our law.

Instead, in our tradition, intellectual property is an instrument.
It sets the groundwork for a richly creative society but remains subservient to the value of creativity.
The current debate has this turned around.
We have become so concerned with protecting the instrument that we are losing sight of the value.

The source of this confusion is a distinction that the law no longer takes care to draw—the distinction between republishing someone's work on the one hand and building upon or transforming that work on the other.
Copyright law at its birth had only publishing as its concern; copyright law today regulates both.

Before the technologies of the Internet, this conflation didn't matter all that much.
The technologies of publishing were expensive; that meant the vast majority of publishing was commercial.
Commercial entities could bear the burden of the law—even the burden of the Byzantine complexity that copyright law has become.
It was just one more expense of doing business.

But with the birth of the Internet, this natural limit to the reach of the law has disappeared.
The law controls not just the creativity of commercial creators but effectively that of anyone.
Although that expansion would not matter much if copyright law regulated only “copying,” when the law regulates as broadly and obscurely as it does, the extension matters a lot.
The burden of this law now vastly outweighs any original benefit—certainly as it affects noncommercial creativity, and increasingly as it affects commercial creativity as well.
Thus, as we'll see more clearly in the chapters below, the law's role is less and less to support creativity, and more and more to protect certain industries against competition.
Just at the time digital technology could unleash an extraordinary range of commercial and noncommercial creativity, the law burdens this creativity with insanely complex and vague rules and with the threat of obscenely severe penalties.
We may be seeing, as Richard Florida writes, the “Rise of the Creative Class.”[^18]
Unfortunately, we are also seeing an extraordinary rise of regulation of this creative class.

These burdens make no sense in our tradition.
We should begin by understanding that tradition a bit more and by placing in their proper context the current battles about behavior labeled “piracy.”

<span id="c1"></span>

## Creators

**In 1928,** a cartoon character was born.
An early Mickey Mouse made his debut in May of that year, in a silent flop called _Plane Crazy_.
In November, in New York City's Colony Theater, in the first widely distributed cartoon synchronized with sound, _Steamboat Willie_ brought to life the character that would become Mickey Mouse.

Synchronized sound had been introduced to film a year earlier in the movie _The Jazz Singer_.
That success led Walt Disney to copy the technique and mix sound with cartoons.
No one knew whether it would work or, if it did work, whether it would win an audience.
But when Disney ran a test in the summer of 1928, the results were unambiguous.
As Disney describes that first experiment,

> A couple of my boys could read music, and one of them could play a mouth organ.
We put them in a room where they could not see the screen and arranged to pipe their sound into the room where our wives and friends were going to see the picture.
>
> The boys worked from a music and sound-effects score.
After several false starts, sound and action got off with the gun.
The mouth organist played the tune, the rest of us in the sound department bammed tin pans and blew slide whistles on the beat.
The synchronization was pretty close.
>
> The effect on our little audience was nothing less than electric.
They responded almost instinctively to this union of sound and motion.
I thought they were kidding me. So they put me in the audience and ran the action again.
It was terrible, but it was wonderful!
And it was something new![^19]

Disney's then partner, and one of animation's most extraordinary talents, Ub Iwerks, put it more strongly: “I have never been so thrilled in my life.
Nothing since has ever equaled it.”

Disney had created something very new, based upon something relatively new.
Synchronized sound brought life to a form of creativity that had rarely—except in Disney's hands—been anything more than filler for other films.
Throughout animation's early history, it was Disney's invention that set the standard that others struggled to match.
And quite often, Disney's great genius, his spark of creativity, was built upon the work of others.

This much is familiar.
What you might not know is that 1928 also marks another important transition.
In that year, a comic (as opposed to cartoon) genius created his last independently produced silent film.
That genius was Buster Keaton.
The film was _Steamboat Bill, Jr_.

Keaton was born into a vaudeville family in 1895\.
In the era of silent film, he had mastered using broad physical comedy as a way to spark uncontrollable laughter from his audience.
_Steamboat Bill, Jr._ was a classic of this form, famous among film buffs for its incredible stunts.
The film was classic Keaton—wildly popular and among the best of its genre.

_Steamboat Bill, Jr._ appeared before Disney's cartoon _Steamboat Willie_.
The coincidence of titles is not coincidental.
Steamboat Willie is a direct cartoon parody of Steamboat Bill,[^20] and both are built upon a common song as a source.
It is not just from the invention of synchronized sound in _The Jazz Singer_ that we get _Steamboat Willie_.
It is also from Buster Keaton's invention of Steamboat Bill, Jr., itself inspired by the song “Steamboat Bill,” that we get Steamboat Willie, and then from Steamboat Willie, Mickey Mouse.

This “borrowing” was nothing unique, either for Disney or for the industry.
Disney was always parroting the feature-length mainstream films of his day.[^21]
So did many others.
Early cartoons are filled with knockoffs—slight variations on winning themes; retellings of ancient stories.
The key to success was the brilliance of the differences.
With Disney, it was sound that gave his animation its spark.
Later, it was the quality of his work relative to the production-line cartoons with which he competed.
Yet these additions were built upon a base that was borrowed.
Disney added to the work of others before him, creating something new out of something just barely old.

Sometimes this borrowing was slight.
Sometimes it was significant.
Think about the fairy tales of the Brothers Grimm.
If you're as oblivious as I was, you're likely to think that these tales are happy, sweet stories, appropriate for any child at bedtime.
In fact, the Grimm fairy tales are, well, for us, grim.
It is a rare and perhaps overly ambitious parent who would dare to read these bloody, moralistic stories to his or her child, at bedtime or anytime.

Disney took these stories and retold them in a way that carried them into a new age.
He animated the stories, with both characters and light.
Without removing the elements of fear and danger altogether, he made funny what was dark and injected a genuine emotion of compassion where before there was fear.
And not just with the work of the Brothers Grimm.
Indeed, the catalog of Disney work drawing upon the work of others is astonishing when set together: _Snow White_ (1937), _Fantasia_ (1940), _Pinocchio_ (1940), _Dumbo_ (1941), _Bambi_ (1942), _Song of the South_ (1946), _Cinderella_ (1950), _Alice in Wonderland_ (1951), _Robin Hood_ (1952), _Peter Pan_ (1953), _Lady and the Tramp_ (1955), _Mulan_ (1998), _Sleeping Beauty_ (1959), _101 Dalmatians_ (1961), _The Sword in the Stone_ (1963), and _The Jungle Book_ (1967)—not to mention a recent example that we should perhaps quickly forget, _Treasure Planet_ (2003). In all of these cases, Disney (or Disney, Inc.) ripped creativity from the culture around him, mixed that creativity with his own extraordinary talent, and then burned that mix into the soul of his culture.
Rip, mix, and burn.

This is a kind of creativity.
It is a creativity that we should remember and celebrate.
There are some who would say that there is no creativity except this kind.
We don't need to go that far to recognize its importance.
We could call this “Disney creativity,” though that would be a bit misleading.
It is, more precisely, “Walt Disney creativity”—a form of expression and genius that builds upon the culture around us and makes it something different.

In 1928, the culture that Disney was free to draw upon was relatively fresh.
The public domain in 1928 was not very old and was therefore quite vibrant.
The average term of copyright was just around thirty years—for that minority of creative work that was in fact copyrighted.[^22]
That means that for thirty years, on average, the authors or copyright holders of a creative work had an “exclusive right” to control certain uses of the work.
To use this copyrighted work in limited ways required the permission of the copyright owner.

At the end of a copyright term, a work passes into the public domain.
No permission is then needed to draw upon or use that work.
No permission and, hence, no lawyers.
The public domain is a “lawyer-free zone.”
Thus, most of the content from the nineteenth century was free for Disney to use and build upon in 1928\. It was free for anyone—whether connected or not, whether rich or not, whether approved or not—to use and build upon.

This is the ways things always were—until quite recently.
For most of our history, the public domain was just over the horizon.
From 1790 until 1978, the average copyright term was never more than thirty-two years, meaning that most culture just a generation and a half old was free for anyone to build upon without the permission of anyone else.
Today's equivalent would be for creative work from the 1960s and 1970s to now be free for the next Walt Disney to build upon without permission.
Yet today, the public domain is presumptive only for content from before the Great Depression.

**Of course,** Walt Disney had no monopoly on “Walt Disney creativity.”
Nor does America.
The norm of free culture has, until recently, and except within totalitarian nations, been broadly exploited and quite universal.

Consider, for example, a form of creativity that seems strange to many Americans but that is inescapable within Japanese culture: _manga_, or comics.
The Japanese are fanatics about comics.
Some 40 percent of publications are comics, and 30 percent of publication revenue derives from comics.
They are everywhere in Japanese society, at every magazine stand, carried by a large proportion of commuters on Japan's extraordinary system of public transportation.

Americans tend to look down upon this form of culture.
That's an unattractive characteristic of ours.
We're likely to misunderstand much about manga, because few of us have ever read anything close to the stories that these “graphic novels” tell.
For the Japanese, manga cover every aspect of social life.
For us, comics are “men in tights.”
And anyway, it's not as if the New York subways are filled with readers of Joyce or even Hemingway.
People of different cultures distract themselves in different ways, the Japanese in this interestingly different way.

But my purpose here is not to understand manga.
It is to describe a variant on manga that from a lawyer's perspective is quite odd, but from a Disney perspective is quite familiar.

This is the phenomenon of _doujinshi_.
Doujinshi are also comics, but they are a kind of copycat comic.
A rich ethic governs the creation of doujinshi.
It is not doujinshi if it is _just_ a copy; the artist must make a contribution to the art he copies, by transforming it either subtly or significantly.
A doujinshi comic can thus take a mainstream comic and develop it differently—with a different story line.
Or the comic can keep the character in character but change its look slightly.
There is no formula for what makes the doujinshi sufficiently “different.”
But they must be different if they are to be considered true doujinshi.
Indeed, there are committees that review doujinshi for inclusion within shows and reject any copycat comic that is merely a copy.

These copycat comics are not a tiny part of the manga market.
They are huge.
More than 33,000 “circles” of creators from across Japan produce these bits of Walt Disney creativity.
More than 450,000 Japanese come together twice a year, in the largest public gathering in the country, to exchange and sell them.
This market exists in parallel to the mainstream commercial manga market.
In some ways, it obviously competes with that market, but there is no sustained effort by those who control the commercial manga market to shut the doujinshi market down.
It flourishes, despite the competition and despite the law.

The most puzzling feature of the doujinshi market, for those trained in the law, at least, is that it is allowed to exist at all.
Under Japanese copyright law, which in this respect (on paper) mirrors American copyright law, the doujinshi market is an illegal one.
Doujinshi are plainly “derivative works.”
There is no general practice by doujinshi artists of securing the permission of the manga creators.
Instead, the practice is simply to take and modify the creations of others, as Walt Disney did with _Steamboat Bill, Jr_.
Under both Japanese and American law, that “taking” without the permission of the original copyright owner is illegal.
It is an infringement of the original copyright to make a copy or a derivative work without the original copyright owner's permission.

Yet this illegal market exists and indeed flourishes in Japan, and in the view of many, it is precisely because it exists that Japanese manga flourish.
As American graphic novelist Judd Winick said to me, “The early days of comics in America are very much like what's going on in Japan now…
American comics were born out of copying each other…
That's how [the artists] learn to draw—by going into comic books and not tracing them, but looking at them and copying them” and building from them.[^23]

American comics now are quite different, Winick explains, in part because of the legal difficulty of adapting comics the way doujinshi are allowed.
Speaking of Superman, Winick told me, “there are these rules and you have to stick to them.”
There are things Superman “cannot” do.
“As a creator, it's frustrating having to stick to some parameters which are fifty years old.”

The norm in Japan mitigates this legal difficulty.
Some say it is precisely the benefit accruing to the Japanese manga market that explains the mitigation.
Temple University law professor Salil Mehra, for example, hypothesizes that the manga market accepts these technical violations because they spur the manga market to be more wealthy and productive.
Everyone would be worse off if doujinshi were banned, so the law does not ban doujinshi.[^24]

The problem with this story, however, as Mehra plainly acknowledges, is that the mechanism producing this laissez faire response is not clear.
It may well be that the market as a whole is better off if doujinshi are permitted rather than banned, but that doesn't explain why individual copyright owners don't sue nonetheless.
If the law has no general exception for doujinshi, and indeed in some cases individual manga artists have sued doujinshi artists, why is there not a more general pattern of blocking this “free taking” by the doujinshi culture?

I spent four wonderful months in Japan, and I asked this question as often as I could.
Perhaps the best account in the end was offered by a friend from a major Japanese law firm.
“We don't have enough lawyers,” he told me one afternoon.
There “just aren't enough resources to prosecute cases like this.”

This is a theme to which we will return: that regulation by law is a function of both the words on the books and the costs of making those words have effect.
For now, focus on the obvious question that is begged: Would Japan be better off with more lawyers?
Would manga be richer if doujinshi artists were regularly prosecuted?
Would the Japanese gain something important if they could end this practice of uncompensated sharing?
Does piracy here hurt the victims of the piracy, or does it help them?
Would lawyers fighting this piracy help their clients or hurt them?

**Let's pause** for a moment.

If you're like I was a decade ago, or like most people are when they first start thinking about these issues, then just about now you should be puzzled about something you hadn't thought through before.

We live in a world that celebrates “property.”
I am one of those celebrants.
I believe in the value of property in general, and I also believe in the value of that weird form of property that lawyers call “intellectual property.”[^25]
A large, diverse society cannot survive without property; a large, diverse, and modern society cannot flourish without intellectual property.

But it takes just a second's reflection to realize that there is plenty of value out there that “property” doesn't capture.
I don't mean “money can't buy you love,” but rather, value that is plainly part of a process of production, including commercial as well as noncommercial production.
If Disney animators had stolen a set of pencils to draw Steamboat Willie, we'd have no hesitation in condemning that taking as wrong—even though trivial, even if unnoticed.
Yet there was nothing wrong, at least under the law of the day, with Disney's taking from Buster Keaton or from the Brothers Grimm.
There was nothing wrong with the taking from Keaton because Disney's use would have been considered “fair.”
There was nothing wrong with the taking from the Grimms because the Grimms' work was in the public domain.

Thus, even though the things that Disney took—or more generally, the things taken by anyone exercising Walt Disney creativity—are valuable, our tradition does not treat those takings as wrong.
Some things remain free for the taking within a free culture, and that freedom is good.

The same with the doujinshi culture.
If a doujinshi artist broke into a publisher's office and ran off with a thousand copies of his latest work—or even one copy—without paying, we'd have no hesitation in saying the artist was wrong.
In addition to having trespassed, he would have stolen something of value.
The law bans that stealing in whatever form, whether large or small.

Yet there is an obvious reluctance, even among Japanese lawyers, to say that the copycat comic artists are “stealing.”
This form of Walt Disney creativity is seen as fair and right, even if lawyers in particular find it hard to say why.

It's the same with a thousand examples that appear everywhere once you begin to look.
Scientists build upon the work of other scientists without asking or paying for the privilege.
(“Excuse me, Professor Einstein, but may I have permission to use your theory of relativity to show that you were wrong about quantum physics?”)
Acting companies perform adaptations of the works of Shakespeare without securing permission from anyone.
(Does _anyone_ believe Shakespeare would be better spread within our culture if there were a central Shakespeare rights clearinghouse that all productions of Shakespeare must appeal to first?)
And Hollywood goes through cycles with a certain kind of movie: five asteroid films in the late 1990s; two volcano disaster films in 1997.

Creators here and everywhere are always and at all times building upon the creativity that went before and that surrounds them now.
That building is always and everywhere at least partially done without permission and without compensating the original creator.
No society, free or controlled, has ever demanded that every use be paid for or that permission for Walt Disney creativity must always be sought.
Instead, every society has left a certain bit of its culture free for the taking—free societies more fully than unfree, perhaps, but all societies to some degree.

The hard question is therefore not _whether_ a culture is free.
All cultures are free to some degree.
The hard question instead is “_How_ free is this culture?” How much, and how broadly, is the culture free for others to take and build upon?
Is that freedom limited to party members?
To members of the royal family?
To the top ten corporations on the New York Stock Exchange?
Or is that freedom spread broadly?
To artists generally, whether affiliated with the Met or not?
To musicians generally, whether white or not?
To filmmakers generally, whether affiliated with a studio or not?

Free cultures are cultures that leave a great deal open for others to build upon; unfree, or permission, cultures leave much less.
Ours was a free culture.
It is becoming much less so.

<span id="c2"></span>

## “Mere Copyists”

**In 1839,** Louis Daguerre invented the first practical technology for producing what we would call “photographs.”
Appropriately enough, they were called “daguerreotypes.”
The process was complicated and expensive, and the field was thus limited to professionals and a few zealous and wealthy amateurs.
(There was even an American Daguerre Association that helped regulate the industry, as do all such associations, by keeping competition down so as to keep prices up.)

Yet despite high prices, the demand for daguerreotypes was strong.
This pushed inventors to find simpler and cheaper ways to make “automatic pictures.”
William Talbot soon discovered a process for making “negatives.”
But because the negatives were glass, and had to be kept wet, the process still remained expensive and cumbersome.
In the 1870s, dry plates were developed, making it easier to separate the taking of a picture from its developing.
These were still plates of glass, and thus it was still not a process within reach of most amateurs.

The technological change that made mass photography possible didn't happen until 1888, and was the creation of a single man.
George Eastman, himself an amateur photographer, was frustrated by the technology of photographs made with plates.
In a flash of insight (so to speak), Eastman saw that if the film could be made to be flexible, it could be held on a single spindle.
That roll could then be sent to a developer, driving the costs of photography down substantially.
By lowering the costs, Eastman expected he could dramatically broaden the population of photographers.

Eastman developed flexible, emulsion-coated paper film and placed rolls of it in small, simple cameras: the Kodak.
The device was marketed on the basis of its simplicity.
“You press the button and we do the rest.”[^26]
As he described in _The Kodak Primer_:

> The principle of the Kodak system is the separation of the work that any person whomsoever can do in making a photograph, from the work that only an expert can do…
We furnish anybody, man, woman or child, who has sufficient intelligence to point a box straight and press a button, with an instrument which altogether removes from the practice of photography the necessity for exceptional facilities or, in fact, any special knowledge of the art.
It can be employed without preliminary study, without a darkroom and without chemicals.[^27]

For $25, anyone could make pictures.
The camera came preloaded with film, and when it had been used, the camera was returned to an Eastman factory, where the film was developed.
Over time, of course, the cost of the camera and the ease with which it could be used both improved.
Roll film thus became the basis for the explosive growth of popular photography.
Eastman's camera first went on sale in 1888; one year later, Kodak was printing more than six thousand negatives a day.
From 1888 through 1909, while industrial production was rising by 4.7 percent, photographic equipment and material sales increased by 11 percent.[^28]
Eastman Kodak's sales during the same period experienced an average annual increase of over 17 percent.[^29]

The real significance of Eastman's invention, however, was not economic.
It was social.
Professional photography gave individuals a glimpse of places they would never otherwise see.
Amateur photography gave them the ability to record their own lives in a way they had never been able to do before.
As author Brian Coe notes, “For the first time the snapshot album provided the man on the street with a permanent record of his family and its activities…
For the first time in history there exists an authentic visual record of the appearance and activities of the common man made without [literary] interpretation or bias.”[^30]

In this way, the Kodak camera and film were technologies of expression.
The pencil or paintbrush was also a technology of expression, of course.
But it took years of training before they could be deployed by amateurs in any useful or effective way.
With the Kodak, expression was possible much sooner and more simply.
The barrier to expression was lowered.
Snobs would sneer at its “quality”; professionals would discount it as irrelevant.
But watch a child study how best to frame a picture and you get a sense of the experience of creativity that the Kodak enabled.
Democratic tools gave ordinary people a way to express themselves more easily than any tools could have before.

What was required for this technology to flourish?
Obviously, Eastman's genius was an important part.
But also important was the legal environment within which Eastman's invention grew.
For early in the history of photography, there was a series of judicial decisions that could well have changed the course of photography substantially.
Courts were asked whether the photographer, amateur or professional, required permission before he could capture and print whatever image he wanted.
Their answer was no.[^31]

The arguments in favor of requiring permission will sound surprisingly familiar.
The photographer was “taking” something from the person or building whose photograph he shot—pirating something of value.
Some even thought he was taking the target's soul.
Just as Disney was not free to take the pencils that his animators used to draw Mickey, so, too, should these photographers not be free to take images that they thought valuable.

On the other side was an argument that should be familiar, as well.
Sure, there may be something of value being used.
But citizens should have the right to capture at least those images that stand in public view.
(Louis Brandeis, who would become a Supreme Court Justice, thought the rule should be different for images from private spaces.[^32])
It may be that this means that the photographer gets something for nothing.
Just as Disney could take inspiration from _Steamboat Bill, Jr_. or the Brothers Grimm, the photographer should be free to capture an image without compensating the source.

Fortunately for Mr. Eastman, and for photography in general, these early decisions went in favor of the pirates.
In general, no permission would be required before an image could be captured and shared with others.
Instead, permission was presumed.
Freedom was the default.
(The law would eventually craft an exception for famous people: commercial photographers who snap pictures of famous people for commercial purposes have more restrictions than the rest of us. But in the ordinary case, the image can be captured without clearing the rights to do the capturing.[^33])

We can only speculate about how photography would have developed had the law gone the other way.
If the presumption had been against the photographer, then the photographer would have had to demonstrate permission.
Perhaps Eastman Kodak would have had to demonstrate permission, too, before it developed the film upon which images were captured.
After all, if permission were not granted, then Eastman Kodak would be benefiting from the “theft” committed by the photographer.
Just as Napster benefited from the copyright infringements committed by Napster users, Kodak would be benefiting from the “image-right” infringement of its photographers.
We could imagine the law then requiring that some form of permission be demonstrated before a company developed pictures.
We could imagine a system developing to demonstrate that permission.

But though we could imagine this system of permission, it would be very hard to see how photography could have flourished as it did if the requirement for permission had been built into the rules that govern it. Photography would have existed.
It would have grown in importance over time.
Professionals would have continued to use the technology as they did—since professionals could have more easily borne the burdens of the permission system.
But the spread of photography to ordinary people would not have occurred.
Nothing like that growth would have been realized.
And certainly, nothing like that growth in a democratic technology of expression would have been realized.

**If you drive** through San Francisco's Presidio, you might see two gaudy yellow school buses painted over with colorful and striking images, and the logo “Just Think!” in place of the name of a school.
But there's little that's “just” cerebral in the projects that these busses enable.
These buses are filled with technologies that teach kids to tinker with film.
Not the film of Eastman.
Not even the film of your VCR.
Rather the “film” of digital cameras.
Just Think! is a project that enables kids to make films, as a way to understand and critique the filmed culture that they find all around them.
Each year, these busses travel to more than thirty schools and enable three hundred to five hundred children to learn something about media by doing something with media.
By doing, they think.
By tinkering, they learn.

These buses are not cheap, but the technology they carry is increasingly so. The cost of a high-quality digital video system has fallen dramatically.
As one analyst puts it, “Five years ago, a good real-time digital video editing system cost $25,000\. Today you can get professional quality for $595.”[^34]
These buses are filled with technology that would have cost hundreds of thousands just ten years ago.
And it is now feasible to imagine not just buses like this, but classrooms across the country where kids are learning more and more of something teachers call “media literacy.”

“Media literacy,” as Dave Yanofsky, the executive director of Just Think!, puts it, “is the ability … to understand, analyze, and deconstruct media images.
Its aim is to make [kids] literate about the way media works, the way it's constructed, the way it's delivered, and the way people access it.”

This may seem like an odd way to think about “literacy.”
For most people, literacy is about reading and writing.
Faulkner and Hemingway and noticing split infinitives are the things that “literate” people know about.

Maybe.
But in a world where children see on average 390 hours of television commercials per year, or between 20,000 and 45,000 commercials generally,[^35] it is increasingly important to understand the “grammar” of media.
For just as there is a grammar for the written word, so, too, is there one for media.
And just as kids learn how to write by writing lots of terrible prose, kids learn how to write media by constructing lots of (at least at first) terrible media.

A growing field of academics and activists sees this form of literacy as crucial to the next generation of culture.
For though anyone who has written understands how difficult writing is—how difficult it is to sequence the story, to keep a reader's attention, to craft language to be understandable—few of us have any real sense of how difficult media is. Or more fundamentally, few of us have a sense of how media works, how it holds an audience or leads it through a story, how it triggers emotion or builds suspense.

It took filmmaking a generation before it could do these things well.
But even then, the knowledge was in the filming, not in writing about the film.
The skill came from experiencing the making of a film, not from reading a book about it. One learns to write by writing and then reflecting upon what one has written.
One learns to write with images by making them and then reflecting upon what one has created.

This grammar has changed as media has changed.
When it was just film, as Elizabeth Daley, executive director of the University of Southern California's Annenberg Center for Communication and dean of the USC School of Cinema-Television, explained to me, the grammar was about “the placement of objects, color, … rhythm, pacing, and texture.”[^36]
But as computers open up an interactive space where a story is “played” as well as experienced, that grammar changes.
The simple control of narrative is lost, and so other techniques are necessary.
Author Michael Crichton had mastered the narrative of science fiction.
But when he tried to design a computer game based on one of his works, it was a new craft he had to learn.
How to lead people through a game without their feeling they have been led was not obvious, even to a wildly successful author.[^37]

This skill is precisely the craft a filmmaker learns.
As Daley describes, “people are very surprised about how they are led through a film. [I]t is perfectly constructed to keep you from seeing it, so you have no idea.
If a filmmaker succeeds you do not know how you were led.”
If you know you were led through a film, the film has failed.

Yet the push for an expanded literacy—one that goes beyond text to include audio and visual elements—is not about making better film directors.
The aim is not to improve the profession of filmmaking at all.
Instead, as Daley explained,

> From my perspective, probably the most important digital divide is not access to a box.
It's the ability to be empowered with the language that that box works in. Otherwise only a very few people can write with this language, and all the rest of us are reduced to being read-only.

“Read-only.”
Passive recipients of culture produced elsewhere.
Couch potatoes.
Consumers.
This is the world of media from the twentieth century.

The twenty-first century could be different.
This is the crucial point: It could be both read and write.
Or at least reading and better understanding the craft of writing.
Or best, reading and understanding the tools that enable the writing to lead or mislead.
The aim of any literacy, and this literacy in particular, is to “empower people to choose the appropriate language for what they need to create or express.”[^38]
It is to enable students “to communicate in the language of the twenty-first century.”[^39]

As with any language, this language comes more easily to some than to others.
It doesn't necessarily come more easily to those who excel in written language.
Daley and Stephanie Barish, director of the Institute for Multimedia Literacy at the Annenberg Center, describe one particularly poignant example of a project they ran in a high school.
The high school was a very poor inner-city Los Angeles school.
In all the traditional measures of success, this school was a failure.
But Daley and Barish ran a program that gave kids an opportunity to use film to express meaning about something the students know something about—gun violence.

The class was held on Friday afternoons, and it created a relatively new problem for the school.
While the challenge in most classes was getting the kids to come, the challenge in this class was keeping them away.
The “kids were showing up at 6 A.M. and leaving at 5 at night,” said Barish.
They were working harder than in any other class to do what education should be about—learning how to express themselves.

Using whatever “free web stuff they could find,” and relatively simple tools to enable the kids to mix “image, sound, and text,” Barish said this class produced a series of projects that showed something about gun violence that few would otherwise understand.
This was an issue close to the lives of these students.
The project “gave them a tool and empowered them to be able to both understand it and talk about it,” Barish explained.
That tool succeeded in creating expression—far more successfully and powerfully than could have been created using only text.
“If you had said to these students, ‘you have to do it in text,' they would've just thrown their hands up and gone and done something else,” Barish described, in part, no doubt, because expressing themselves in text is not something these students can do well.
Yet neither is text a form in which _these_ ideas can be expressed well.
The power of this message depended upon its connection to this form of expression.

“But isn't education about teaching kids to write?” I asked.
In part, of course, it is. But why are we teaching kids to write?
Education, Daley explained, is about giving students a way of “constructing meaning.”
To say that that means just writing is like saying teaching writing is only about teaching kids how to spell.
Text is one part—and increasingly, not the most powerful part—of constructing meaning.
As Daley explained in the most moving part of our interview,

> What you want is to give these students ways of constructing meaning.
If all you give them is text, they're not going to do it. Because they can't. You know, you've got Johnny who can look at a video, he can play a video game, he can do graffiti all over your walls, he can take your car apart, and he can do all sorts of other things.
He just can't read your text.
So Johnny comes to school and you say, “Johnny, you're illiterate.
Nothing you can do matters.”
Well, Johnny then has two choices: He can dismiss you or he [can] dismiss himself.
If his ego is healthy at all, he's going to dismiss you. [But i]nstead, if you say, “Well, with all these things that you can do, let's talk about this issue.
Play for me music that you think reflects that, or show me images that you think reflect that, or draw for me something that reflects that.”
Not by giving a kid a video camera and … saying, “Let's go have fun with the video camera and make a little movie.”
But instead, really help you take these elements that you understand, that are your language, and construct meaning about the topic…
>
> That empowers enormously.
And then what happens, of course, is eventually, as it has happened in all these classes, they bump up against the fact, “I need to explain this and I really need to write something.”
And as one of the teachers told Stephanie, they would rewrite a paragraph 5, 6, 7, 8 times, till they got it right.
>
> Because they needed to. There was a reason for doing it. They needed to say something, as opposed to just jumping through your hoops.
They actually needed to use a language that they didn't speak very well.
But they had come to understand that they had a lot of power with this language.

**When two planes** crashed into the World Trade Center, another into the Pentagon, and a fourth into a Pennsylvania field, all media around the world shifted to this news.
Every moment of just about every day for that week, and for weeks after, television in particular, and media generally, retold the story of the events we had just witnessed.
The telling was a retelling, because we had seen the events that were described.
The genius of this awful act of terrorism was that the delayed second attack was perfectly timed to assure that the whole world would be watching.

These retellings had an increasingly familiar feel.
There was music scored for the intermissions, and fancy graphics that flashed across the screen.
There was a formula to interviews.
There was “balance,” and seriousness.
This was news choreographed in the way we have increasingly come to expect it, “news as entertainment,” even if the entertainment is tragedy.

But in addition to this produced news about the “tragedy of September 11,” those of us tied to the Internet came to see a very different production as well.
The Internet was filled with accounts of the same events.
Yet these Internet accounts had a very different flavor.
Some people constructed photo pages that captured images from around the world and presented them as slide shows with text.
Some offered open letters.
There were sound recordings.
There was anger and frustration.
There were attempts to provide context.
There was, in short, an extraordinary worldwide barn raising, in the sense Mike Godwin uses the term in his book _Cyber Rights_, around a news event that had captured the attention of the world.
There was ABC and CBS, but there was also the Internet.

I don't mean simply to praise the Internet—though I do think the people who supported this form of speech should be praised.
I mean instead to point to a significance in this form of speech.
For like a Kodak, the Internet enables people to capture images.
And like in a movie by a student on the “Just Think!” bus, the visual images could be mixed with sound or text.

But unlike any technology for simply capturing images, the Internet allows these creations to be shared with an extraordinary number of people, practically instantaneously.
This is something new in our tradition—not just that culture can be captured mechanically, and obviously not just that events are commented upon critically, but that this mix of captured images, sound, and commentary can be widely spread practically instantaneously.

September 11 was not an aberration.
It was a beginning.
Around the same time, a form of communication that has grown dramatically was just beginning to come into public consciousness: the Web-log, or blog.
The blog is a kind of public diary, and within some cultures, such as in Japan, it functions very much like a diary.
In those cultures, it records private facts in a public way—it's a kind of electronic _Jerry Springer_, available anywhere in the world.

But in the United States, blogs have taken on a very different character.
There are some who use the space simply to talk about their private life.
But there are many who use the space to engage in public discourse.
Discussing matters of public import, criticizing others who are mistaken in their views, criticizing politicians about the decisions they make, offering solutions to problems we all see: blogs create the sense of a virtual public meeting, but one in which we don't all hope to be there at the same time and in which conversations are not necessarily linked.
The best of the blog entries are relatively short; they point directly to words used by others, criticizing with or adding to them.
They are arguably the most important form of unchoreographed public discourse that we have.

That's a strong statement.
Yet it says as much about our democracy as it does about blogs.
This is the part of America that is most difficult for those of us who love America to accept: Our democracy has atrophied.
Of course we have elections, and most of the time the courts allow those elections to count.
A relatively small number of people vote in those elections.
The cycle of these elections has become totally professionalized and routinized.
Most of us think this is democracy.

But democracy has never just been about elections.
Democracy means rule by the people, but rule means something more than mere elections.
In our tradition, it also means control through reasoned discourse.
This was the idea that captured the imagination of Alexis de Tocqueville, the nineteenth-century French lawyer who wrote the most important account of early “Democracy in America.”
It wasn't popular elections that fascinated him—it was the jury, an institution that gave ordinary people the right to choose life or death for other citizens.
And most fascinating for him was that the jury didn't just vote about the outcome they would impose.
They deliberated.
Members argued about the “right” result; they tried to persuade each other of the “right” result, and in criminal cases at least, they had to agree upon a unanimous result for the process to come to an end.[^40]

Yet even this institution flags in American life today.
And in its place, there is no systematic effort to enable citizen deliberation.
Some are pushing to create just such an institution.[^41]
And in some towns in New England, something close to deliberation remains.
But for most of us for most of the time, there is no time or place for “democratic deliberation” to occur.

More bizarrely, there is generally not even permission for it to occur.
We, the most powerful democracy in the world, have developed a strong norm against talking about politics.
It's fine to talk about politics with people you agree with.
But it is rude to argue about politics with people you disagree with.
Political discourse becomes isolated, and isolated discourse becomes more extreme.[^42]
We say what our friends want to hear, and hear very little beyond what our friends say.

Enter the blog.
The blog's very architecture solves one part of this problem.
People post when they want to post, and people read when they want to read.
The most difficult time is synchronous time.
Technologies that enable asynchronous communication, such as e-mail, increase the opportunity for communication.
Blogs allow for public discourse without the public ever needing to gather in a single public place.

But beyond architecture, blogs also have solved the problem of norms.
There's no norm (yet) in blog space not to talk about politics.
Indeed, the space is filled with political speech, on both the right and the left.
Some of the most popular sites are conservative or libertarian, but there are many of all political stripes.
And even blogs that are not political cover political issues when the occasion merits.

The significance of these blogs is tiny now, though not so tiny.
The name Howard Dean may well have faded from the 2004 presidential race but for blogs.
Yet even if the number of readers is small, the reading is having an effect.

One direct effect is on stories that had a different life cycle in the mainstream media.
The Trent Lott affair is an example.
When Lott “misspoke” at a party for Senator Strom Thurmond, essentially praising Thurmond's segregationist policies, he calculated correctly that this story would disappear from the mainstream press within forty-eight hours.
It did.
But he didn't calculate its life cycle in blog space.
The bloggers kept researching the story.
Over time, more and more instances of the same “misspeaking” emerged.
Finally, the story broke back into the mainstream press.
In the end, Lott was forced to resign as senate majority leader.[^43]

This different cycle is possible because the same commercial pressures don't exist with blogs as with other ventures.
Television and newspapers are commercial entities.
They must work to keep attention.
If they lose readers, they lose revenue.
Like sharks, they must move on.

But bloggers don't have a similar constraint.
They can obsess, they can focus, they can get serious.
If a particular blogger writes a particularly interesting story, more and more people link to that story.
And as the number of links to a particular story increases, it rises in the ranks of stories.
People read what is popular; what is popular has been selected by a very democratic process of peer-generated rankings.

There's a second way, as well, in which blogs have a different cycle from the mainstream press.
As Dave Winer, one of the fathers of this movement and a software author for many decades, told me, another difference is the absence of a financial “conflict of interest.” “I think you have to take the conflict of interest” out of journalism, Winer told me.
“An amateur journalist simply doesn't have a conflict of interest, or the conflict of interest is so easily disclosed that you know you can sort of get it out of the way.”

These conflicts become more important as media becomes more concentrated (more on this below). A concentrated media can hide more from the public than an unconcentrated media can—as CNN admitted it did after the Iraq war because it was afraid of the consequences to its own employees.[^44]
It also needs to sustain a more coherent account.
(In the middle of the Iraq war, I read a post on the Internet from someone who was at that time listening to a satellite uplink with a reporter in Iraq.
The New York headquarters was telling the reporter over and over that her account of the war was too bleak: She needed to offer a more optimistic story.
When she told New York that wasn't warranted, they told her that _they_ were writing “the story.”)

Blog space gives amateurs a way to enter the debate—“amateur” not in the sense of inexperienced, but in the sense of an Olympic athlete, meaning not paid by anyone to give their reports.
It allows for a much broader range of input into a story, as reporting on the Columbia disaster revealed, when hundreds from across the southwest United States turned to the Internet to retell what they had seen.[^45]
And it drives readers to read across the range of accounts and “triangulate,” as Winer puts it, the truth.
Blogs, Winer says, are “communicating directly with our constituency, and the middle man is out of it”—with all the benefits, and costs, that might entail.

Winer is optimistic about the future of journalism infected with blogs.
“It's going to become an essential skill,” Winer predicts, for public figures and increasingly for private figures as well.
It's not clear that “journalism” is happy about this—some journalists have been told to curtail their blogging.[^46]
But it is clear that we are still in transition.
“A lot of what we are doing now is warm-up exercises,” Winer told me. There is a lot that must mature before this space has its mature effect.
And as the inclusion of content in this space is the least infringing use of the Internet (meaning infringing on copyright), Winer said, “we will be the last thing that gets shut down.”

This speech affects democracy.
Winer thinks that happens because “you don't have to work for somebody who controls, [for] a gate-keeper.”
That is true.
But it affects democracy in another way as well.
As more and more citizens express what they think, and defend it in writing, that will change the way people understand public issues.
It is easy to be wrong and misguided in your head.
It is harder when the product of your mind can be criticized by others.
Of course, it is a rare human who admits that he has been persuaded that he is wrong.
But it is even rarer for a human to ignore when he has been proven wrong.
The writing of ideas, arguments, and criticism improves democracy.
Today there are probably a couple of million blogs where such writing happens.
When there are ten million, there will be something extraordinary to report.

**John Seely Brown** is the chief scientist of the Xerox Corporation.
His work, as his Web site describes it, is “human learning and … the creation of knowledge ecologies for creating … innovation.”

Brown thus looks at these technologies of digital creativity a bit differently from the perspectives I've sketched so far.
I'm sure he would be excited about any technology that might improve democracy.
But his real excitement comes from how these technologies affect learning.

As Brown believes, we learn by tinkering.
When “a lot of us grew up,” he explains, that tinkering was done “on motorcycle engines, lawn-mower engines, automobiles, radios, and so on.”
But digital technologies enable a different kind of tinkering—with abstract ideas though in concrete form.
The kids at Just Think! not only think about how a commercial portrays a politician; using digital technology, they can take the commercial apart and manipulate it, tinker with it to see how it does what it does.
Digital technologies launch a kind of bricolage, or “free collage,” as Brown calls it. Many get to add to or transform the tinkering of many others.

The best large-scale example of this kind of tinkering so far is free software or open-source software (FS/OSS). FS/OSS is software whose source code is shared.
Anyone can download the technology that makes a FS/OSS program run.
And anyone eager to learn how a particular bit of FS/OSS technology works can tinker with the code.

This opportunity creates a “completely new kind of learning platform,” as Brown describes.
“As soon as you start doing that, you … unleash a free collage on the community, so that other people can start looking at your code, tinkering with it, trying it out, seeing if they can improve it.”
Each effort is a kind of apprenticeship.
“Open source becomes a major apprenticeship platform.”

In this process, “the concrete things you tinker with are abstract.
They are code.”
Kids are “shifting to the ability to tinker in the abstract, and this tinkering is no longer an isolated activity that you're doing in your garage.
You are tinkering with a community platform…
You are tinkering with other people's stuff.
The more you tinker the more you improve.”
The more you improve, the more you learn.

This same thing happens with content, too.
And it happens in the same collaborative way when that content is part of the Web.
As Brown puts it, “the Web [is] the first medium that truly honors multiple forms of intelligence.”
Earlier technologies, such as the typewriter or word processors, helped amplify text.
But the Web amplifies much more than text.
“The Web … says if you are musical, if you are artistic, if you are visual, if you are interested in film … [then] there is a lot you can start to do on this medium. [It] can now amplify and honor these multiple forms of intelligence.”

Brown is talking about what Elizabeth Daley, Stephanie Barish, and Just Think! teach: that this tinkering with culture teaches as well as creates.
It develops talents differently, and it builds a different kind of recognition.

Yet the freedom to tinker with these objects is not guaranteed.
Indeed, as we'll see through the course of this book, that freedom is increasingly highly contested.
While there's no doubt that your father had the right to tinker with the car engine, there's great doubt that your child will have the right to tinker with the images she finds all around.
The law and, increasingly, technology interfere with a freedom that technology, and curiosity, would otherwise ensure.

These restrictions have become the focus of researchers and scholars.
Professor Ed Felten of Princeton (whom we'll see more of in chapter 10) has developed a powerful argument in favor of the “right to tinker” as it applies to computer science and to knowledge in general.[^47]
But Brown's concern is earlier, or younger, or more fundamental.
It is about the learning that kids can do, or can't do, because of the law.

“This is where education in the twenty-first century is going,” Brown explains.
We need to “understand how kids who grow up digital think and want to learn.”

“Yet,” as Brown continued, and as the balance of this book will evince, “we are building a legal system that completely suppresses the natural tendencies of today's digital kids…
We're building an architecture that unleashes 60 percent of the brain [and] a legal system that closes down that part of the brain.”

We're building a technology that takes the magic of Kodak, mixes moving images and sound, and adds a space for commentary and an opportunity to spread that creativity everywhere.
But we're building the law to close down that technology.

“No way to run a culture,” as Brewster Kahle, whom we'll meet in chapter 9, quipped to me in a rare moment of despondence.

<span id="c3"></span>

## Catalogs

**In the fall of** 2002, Jesse Jordan of Oceanside, New York, enrolled as a freshman at Rensselaer Polytechnic Institute, in Troy, New York.
His major at RPI was information technology.
Though he is not a programmer, in October Jesse decided to begin to tinker with search engine technology that was available on the RPI network.

RPI is one of America's foremost technological research institutions.
It offers degrees in fields ranging from architecture and engineering to information sciences.
More than 65 percent of its five thousand undergraduates finished in the top 10 percent of their high school class.
The school is thus a perfect mix of talent and experience to imagine and then build, a generation for the network age.

RPI's computer network links students, faculty, and administration to one another.
It also links RPI to the Internet.
Not everything available on the RPI network is available on the Internet.
But the network is designed to enable students to get access to the Internet, as well as more intimate access to other members of the RPI community.

Search engines are a measure of a network's intimacy.
Google brought the Internet much closer to all of us by fantastically improving the quality of search on the network.
Specialty search engines can do this even better.
The idea of “intranet” search engines, search engines that search within the network of a particular institution, is to provide users of that institution with better access to material from that institution.
Businesses do this all the time, enabling employees to have access to material that people outside the business can't get.
Universities do it as well.

These engines are enabled by the network technology itself.
Microsoft, for example, has a network file system that makes it very easy for search engines tuned to that network to query the system for information about the publicly (within that network) available content.
Jesse's search engine was built to take advantage of this technology.
It used Microsoft's network file system to build an index of all the files available within the RPI network.

Jesse's wasn't the first search engine built for the RPI network.
Indeed, his engine was a simple modification of engines that others had built.
His single most important improvement over those engines was to fix a bug within the Microsoft file-sharing system that could cause a user's computer to crash.
With the engines that existed before, if you tried to access a file through a Windows browser that was on a computer that was off-line, your computer could crash.
Jesse modified the system a bit to fix that problem, by adding a button that a user could click to see if the machine holding the file was still on-line.

Jesse's engine went on-line in late October.
Over the following six months, he continued to tweak it to improve its functionality.
By March, the system was functioning quite well.
Jesse had more than one million files in his directory, including every type of content that might be on users' computers.

Thus the index his search engine produced included pictures, which students could use to put on their own Web sites; copies of notes or research; copies of information pamphlets; movie clips that students might have created; university brochures—basically anything that users of the RPI network made available in a public folder of their computer.

But the index also included music files.
In fact, one quarter of the files that Jesse's search engine listed were music files.
But that means, of course, that three quarters were not, and—so that this point is absolutely clear—Jesse did nothing to induce people to put music files in their public folders.
He did nothing to target the search engine to these files.
He was a kid tinkering with a Google-like technology at a university where he was studying information science, and hence, tinkering was the aim.
Unlike Google, or Microsoft, for that matter, he made no money from this tinkering; he was not connected to any business that would make any money from this experiment.
He was a kid tinkering with technology in an environment where tinkering with technology was precisely what he was supposed to do.

On April 3, 2003, Jesse was contacted by the dean of students at RPI.
The dean informed Jesse that the Recording Industry Association of America, the RIAA, would be filing a lawsuit against him and three other students whom he didn't even know, two of them at other universities.
A few hours later, Jesse was served with papers from the suit.
As he read these papers and watched the news reports about them, he was increasingly astonished.

“It was absurd,” he told me.
“I don't think I did anything wrong…
I don't think there's anything wrong with the search engine that I ran or … what I had done to it. I mean, I hadn't modified it in any way that promoted or enhanced the work of pirates.
I just modified the search engine in a way that would make it easier to use”—again, a _search engine_, which Jesse had not himself built, using the Windows file-sharing system, which Jesse had not himself built, to enable members of the RPI community to get access to content, which Jesse had not himself created or posted, and the vast majority of which had nothing to do with music.

But the RIAA branded Jesse a pirate.
They claimed he operated a network and had therefore “willfully” violated copyright laws.
They demanded that he pay them the damages for his wrong.
For cases of “willful infringement,” the Copyright Act specifies something lawyers call “statutory damages.”
These damages permit a copyright owner to claim $150,000 per infringement.
As the RIAA alleged more than one hundred specific copyright infringements, they therefore demanded that Jesse pay them at least $15,000,000.

Similar lawsuits were brought against three other students: one other student at RPI, one at Michigan Technical University, and one at Princeton.
Their situations were similar to Jesse's. Though each case was different in detail, the bottom line in each was exactly the same: huge demands for “damages” that the RIAA claimed it was entitled to. If you added up the claims, these four lawsuits were asking courts in the United States to award the plaintiffs close to $100 _billion_—six times the _total_ profit of the film industry in 2001.[^48]

Jesse called his parents.
They were supportive but a bit frightened.
An uncle was a lawyer.
He began negotiations with the RIAA.
They demanded to know how much money Jesse had.
Jesse had saved $12,000 from summer jobs and other employment.
They demanded $12,000 to dismiss the case.

The RIAA wanted Jesse to admit to doing something wrong.
He refused.
They wanted him to agree to an injunction that would essentially make it impossible for him to work in many fields of technology for the rest of his life.
He refused.
They made him understand that this process of being sued was not going to be pleasant.
(As Jesse's father recounted to me, the chief lawyer on the case, Matt Oppenheimer, told Jesse, “You don't want to pay another visit to a dentist like me.”) And throughout, the RIAA insisted it would not settle the case until it took every penny Jesse had saved.

Jesse's family was outraged at these claims.
They wanted to fight.
But Jesse's uncle worked to educate the family about the nature of the American legal system.
Jesse could fight the RIAA.
He might even win.
But the cost of fighting a lawsuit like this, Jesse was told, would be at least $250,000\. If he won, he would not recover that money.
If he won, he would have a piece of paper saying he had won, and a piece of paper saying he and his family were bankrupt.

So Jesse faced a mafia-like choice: $250,000 and a chance at winning, or $12,000 and a settlement.

The recording industry insists this is a matter of law and morality.
Let's put the law aside for a moment and think about the morality.
Where is the morality in a lawsuit like this?
What is the virtue in scapegoatism?
The RIAA is an extraordinarily powerful lobby.
The president of the RIAA is reported to make more than $1 million a year.
Artists, on the other hand, are not well paid.
The average recording artist makes $45,900.[^49]
There are plenty of ways for the RIAA to affect and direct policy.
So where is the morality in taking money from a student for running a search engine?[^50]

On June 23, Jesse wired his savings to the lawyer working for the RIAA.
The case against him was then dismissed.
And with this, this kid who had tinkered a computer into a $15 million lawsuit became an activist:

> I was definitely not an activist [before]. I never really meant to be an activist… [But] I've been pushed into this.
In no way did I ever foresee anything like this, but I think it's just completely absurd what the RIAA has done.

Jesse's parents betray a certain pride in their reluctant activist.
As his father told me, Jesse “considers himself very conservative, and so do I…
He's not a tree hugger…
I think it's bizarre that they would pick on him.
But he wants to let people know that they're sending the wrong message.
And he wants to correct the record.”

<span id="c4"></span>

## “Pirates”

**If “piracy” means** using the creative property of others without their permission—if “if value, then right” is true—then the history of the content industry is a history of piracy.
Every important sector of “big media” today—film, records, radio, and cable TV—was born of a kind of piracy so defined.
The consistent story is how last generation's pirates join this generation's country club—until now.

### Film

The film industry of Hollywood was built by fleeing pirates.[^51]
Creators and directors migrated from the East Coast to California in the early twentieth century in part to escape controls that patents granted the inventor of filmmaking, Thomas Edison.
These controls were exercised through a monopoly “trust,” the Motion Pictures Patents Company, and were based on Thomas Edison's creative property—patents.
Edison formed the MPPC to exercise the rights this creative property gave him, and the MPPC was serious about the control it demanded.
As one commentator tells one part of the story,

> A January 1909 deadline was set for all companies to comply with the license.
By February, unlicensed outlaws, who referred to themselves as independents protested the trust and carried on business without submitting to the Edison monopoly.
In the summer of 1909 the independent movement was in full-swing, with producers and theater owners using illegal equipment and imported film stock to create their own underground market.
>
> With the country experiencing a tremendous expansion in the number of nickelodeons, the Patents Company reacted to the independent movement by forming a strong-arm subsidiary known as the General Film Company to block the entry of non-licensed independents.
With coercive tactics that have become legendary, General Film confiscated unlicensed equipment, discontinued product supply to theaters which showed unlicensed films, and effectively monopolized distribution with the acquisition of all U.S. film exchanges, except for the one owned by the independent William Fox who defied the Trust even after his license was revoked.[^52]

The Napsters of those days, the “independents,” were companies like Fox.
And no less than today, these independents were vigorously resisted.
“Shooting was disrupted by machinery stolen, and ‘accidents' resulting in loss of negatives, equipment, buildings and sometimes life and limb frequently occurred.”[^53]
That led the independents to flee the East Coast.
California was remote enough from Edison's reach that filmmakers there could pirate his inventions without fear of the law.
And the leaders of Hollywood filmmaking, Fox most prominently, did just that.

Of course, California grew quickly, and the effective enforcement of federal law eventually spread west.
But because patents grant the patent holder a truly “limited” monopoly (just seventeen years at that time), by the time enough federal marshals appeared, the patents had expired.
A new industry had been born, in part from the piracy of Edison's creative property.

### Recorded Music

The record industry was born of another kind of piracy, though to see how requires a bit of detail about the way the law regulates music.

At the time that Edison and Henri Fourneaux invented machines for reproducing music (Edison the phonograph, Fourneaux the player piano), the law gave composers the exclusive right to control copies of their music and the exclusive right to control public performances of their music.
In other words, in 1900, if I wanted a copy of Phil Russel's 1899 hit “Happy Mose,” the law said I would have to pay for the right to get a copy of the musical score, and I would also have to pay for the right to perform it publicly.

But what if I wanted to record “Happy Mose,” using Edison's phonograph or Fourneaux's player piano?
Here the law stumbled.
It was clear enough that I would have to buy any copy of the musical score that I performed in making this recording.
And it was clear enough that I would have to pay for any public performance of the work I was recording.
But it wasn't totally clear that I would have to pay for a “public performance” if I recorded the song in my own house (even today, you don't owe the Beatles anything if you sing their songs in the shower), or if I recorded the song from memory (copies in your brain are not—yet—regulated by copyright law). So if I simply sang the song into a recording device in the privacy of my own home, it wasn't clear that I owed the composer anything.
And more importantly, it wasn't clear whether I owed the composer anything if I then made copies of those recordings.
Because of this gap in the law, then, I could effectively pirate someone else's song without paying its composer anything.

The composers (and publishers) were none too happy about this capacity to pirate.
As South Dakota senator Alfred Kittredge put it,

> Imagine the injustice of the thing.
A composer writes a song or an opera.
A publisher buys at great expense the rights to the same and copyrights it. Along come the phonographic companies and companies who cut music rolls and deliberately steal the work of the brain of the composer and publisher without any regard for [their] rights.[^54]

The innovators who developed the technology to record other people's works were “sponging upon the toil, the work, the talent, and genius of American composers,”[^55] and the “music publishing industry” was thereby “at the complete mercy of this one pirate.”[^56]
As John Philip Sousa put it, in as direct a way as possible, “When they make money out of my pieces, I want a share of it.”[^57]

These arguments have familiar echoes in the wars of our day.
So, too, do the arguments on the other side.
The innovators who developed the player piano argued that “it is perfectly demonstrable that the introduction of automatic music players has not deprived any composer of anything he had before their introduction.”
Rather, the machines increased the sales of sheet music.[^58]
In any case, the innovators argued, the job of Congress was “to consider first the interest of [the public], whom they represent, and whose servants they are.” “All talk about ‘theft,'” the general counsel of the American Graphophone Company wrote, “is the merest claptrap, for there exists no property in ideas musical, literary or artistic, except as defined by statute.”[^59]

The law soon resolved this battle in favor of the composer _and_ the recording artist.
Congress amended the law to make sure that composers would be paid for the “mechanical reproductions” of their music.
But rather than simply granting the composer complete control over the right to make mechanical reproductions, Congress gave recording artists a right to record the music, at a price set by Congress, once the composer allowed it to be recorded once.
This is the part of copyright law that makes cover songs possible.
Once a composer authorizes a recording of his song, others are free to record the same song, so long as they pay the original composer a fee set by the law.

American law ordinarily calls this a “compulsory license,” but I will refer to it as a “statutory license.”
A statutory license is a license whose key terms are set by law.
After Congress's amendment of the Copyright Act in 1909, record companies were free to distribute copies of recordings so long as they paid the composer (or copyright holder) the fee set by the statute.

This is an exception within the law of copyright.
When John Grisham writes a novel, a publisher is free to publish that novel only if Grisham gives the publisher permission.
Grisham, in turn, is free to charge whatever he wants for that permission.
The price to publish Grisham is thus set by Grisham, and copyright law ordinarily says you have no permission to use Grisham's work except with permission of Grisham.

But the law governing recordings gives recording artists less.
And thus, in effect, the law _subsidizes_ the recording industry through a kind of piracy—by giving recording artists a weaker right than it otherwise gives creative authors.
The Beatles have less control over their creative work than Grisham does.
And the beneficiaries of this less control are the recording industry and the public.
The recording industry gets something of value for less than it otherwise would pay; the public gets access to a much wider range of musical creativity.
Indeed, Congress was quite explicit about its reasons for granting this right.
Its fear was the monopoly power of rights holders, and that that power would stifle follow-on creativity.[^60]

While the recording industry has been quite coy about this recently, historically it has been quite a supporter of the statutory license for records.
As a 1967 report from the House Committee on the Judiciary relates,

> the record producers argued vigorously that the compulsory license system must be retained.
They asserted that the record industry is a half-billion-dollar business of great economic importance in the United States and throughout the world; records today are the principal means of disseminating music, and this creates special problems, since performers need unhampered access to musical material on nondiscriminatory terms.
Historically, the record producers pointed out, there were no recording rights before 1909 and the 1909 statute adopted the compulsory license as a deliberate anti-monopoly condition on the grant of these rights.
They argue that the result has been an outpouring of recorded music, with the public being given lower prices, improved quality, and a greater choice.[^61]

By limiting the rights musicians have, by partially pirating their creative work, the record producers, and the public, benefit.

### Radio

Radio was also born of piracy.

When a radio station plays a record on the air, that constitutes a “public performance” of the composer's work.[^62]
As I described above, the law gives the composer (or copyright holder) an exclusive right to public performances of his work.
The radio station thus owes the composer money for that performance.

But when the radio station plays a record, it is not only performing a copy of the _composer's_ work.
The radio station is also performing a copy of the _recording artist's_ work.
It's one thing to have “Happy Birthday” sung on the radio by the local children's choir; it's quite another to have it sung by the Rolling Stones or Lyle Lovett.
The recording artist is adding to the value of the composition performed on the radio station.
And if the law were perfectly consistent, the radio station would have to pay the recording artist for his work, just as it pays the composer of the music for his work.

But it doesn't. Under the law governing radio performances, the radio station does not have to pay the recording artist.
The radio station need only pay the composer.
The radio station thus gets a bit of something for nothing.
It gets to perform the recording artist's work for free, even if it must pay the composer something for the privilege of playing the song.

This difference can be huge.
Imagine you compose a piece of music.
Imagine it is your first.
You own the exclusive right to authorize public performances of that music.
So if Madonna wants to sing your song in public, she has to get your permission.

Imagine she does sing your song, and imagine she likes it a lot.
She then decides to make a recording of your song, and it becomes a top hit.
Under our law, every time a radio station plays your song, you get some money.
But Madonna gets nothing, save the indirect effect on the sale of her CDs.
The public performance of her recording is not a “protected” right.
The radio station thus gets to _pirate_ the value of Madonna's work without paying her anything.

No doubt, one might argue that, on balance, the recording artists benefit.
On average, the promotion they get is worth more than the performance rights they give up. Maybe.
But even if so, the law ordinarily gives the creator the right to make this choice.
By making the choice for him or her, the law gives the radio station the right to take something for nothing.

### Cable TV

Cable TV was also born of a kind of piracy.

When cable entrepreneurs first started wiring communities with cable television in 1948, most refused to pay broadcasters for the content that they echoed to their customers.
Even when the cable companies started selling access to television broadcasts, they refused to pay for what they sold.
Cable companies were thus Napsterizing broadcasters' content, but more egregiously than anything Napster ever did—Napster never charged for the content it enabled others to give away.

Broadcasters and copyright owners were quick to attack this theft.
Rosel Hyde, chairman of the FCC, viewed the practice as a kind of “unfair and potentially destructive competition.”[^63]
There may have been a “public interest” in spreading the reach of cable TV, but as Douglas Anello, general counsel to the National Association of Broadcasters, asked Senator Quentin Burdick during testimony, “Does public interest dictate that you use somebody else's property?”[^64]
As another broadcaster put it,

> The extraordinary thing about the CATV business is that it is the only business I know of where the product that is being sold is not paid for.[^65]

Again, the demand of the copyright holders seemed reasonable enough:

> All we are asking for is a very simple thing, that people who now take our property for nothing pay for it. We are trying to stop piracy and I don't think there is any lesser word to describe it. I think there are harsher words which would fit it.[^66]

These were “free-ride[rs],” Screen Actor's Guild president Charlton Heston said, who were “depriving actors of compensation.”[^67]

But again, there was another side to the debate.
As Assistant Attorney General Edwin Zimmerman put it,

> Our point here is that unlike the problem of whether you have any copyright protection at all, the problem here is whether copyright holders who are already compensated, who already have a monopoly, should be permitted to extend that monopoly…
The question here is how much compensation they should have and how far back they should carry their right to compensation.[^68]

Copyright owners took the cable companies to court.
Twice the Supreme Court held that the cable companies owed the copyright owners nothing.

It took Congress almost thirty years before it resolved the question of whether cable companies had to pay for the content they “pirated.”
In the end, Congress resolved this question in the same way that it resolved the question about record players and player pianos.
Yes, cable companies would have to pay for the content that they broadcast; but the price they would have to pay was not set by the copyright owner.
The price was set by law, so that the broadcasters couldn't exercise veto power over the emerging technologies of cable.
Cable companies thus built their empire in part upon a “piracy” of the value created by broadcasters' content.

**These separate stories** sing a common theme.
If “piracy” means using value from someone else's creative property without permission from that creator—as it is increasingly described today[^69]—then _every_ industry affected by copyright today is the product and beneficiary of a certain kind of piracy.
Film, records, radio, cable TV…
The list is long and could well be expanded.
Every generation welcomes the pirates from the last.
Every generation—until now.

<span id="c5"></span>

## “Piracy”

**There is piracy** of copyrighted material.
Lots of it. This piracy comes in many forms.
The most significant is commercial piracy, the unauthorized taking of other people's content within a commercial context.
Despite the many justifications that are offered in its defense, this taking is wrong.
No one should condone it, and the law should stop it.

But as well as copy-shop piracy, there is another kind of “taking” that is more directly related to the Internet.
That taking, too, seems wrong to many, and it is wrong much of the time.
Before we paint this taking “piracy,” however, we should understand its nature a bit more.
For the harm of this taking is significantly more ambiguous than outright copying, and the law should account for that ambiguity, as it has so often done in the past.

### Piracy I

All across the world, but especially in Asia and Eastern Europe, there are businesses that do nothing but take others people's copyrighted content, copy it, and sell it—all without the permission of a copyright owner.
The recording industry estimates that it loses about $4.6 billion every year to physical piracy[^70] (that works out to one in three CDs sold worldwide). The MPAA estimates that it loses $3 billion annually worldwide to piracy.

This is piracy plain and simple.
Nothing in the argument of this book, nor in the argument that most people make when talking about the subject of this book, should draw into doubt this simple point: This piracy is wrong.

Which is not to say that excuses and justifications couldn't be made for it. We could, for example, remind ourselves that for the first one hundred years of the American Republic, America did not honor foreign copyrights.
We were born, in this sense, a pirate nation.
It might therefore seem hypocritical for us to insist so strongly that other developing nations treat as wrong what we, for the first hundred years of our existence, treated as right.

That excuse isn't terribly strong.
Technically, our law did not ban the taking of foreign works.
It explicitly limited itself to American works.
Thus the American publishers who published foreign works without the permission of foreign authors were not violating any rule.
The copy shops in Asia, by contrast, are violating Asian law.
Asian law does protect foreign copyrights, and the actions of the copy shops violate that law.
So the wrong of piracy that they engage in is not just a moral wrong, but a legal wrong, and not just an internationally legal wrong, but a locally legal wrong as well.

True, these local rules have, in effect, been imposed upon these countries.
No country can be part of the world economy and choose not to protect copyright internationally.
We may have been born a pirate nation, but we will not allow any other nation to have a similar childhood.

If a country is to be treated as a sovereign, however, then its laws are its laws regardless of their source.
The international law under which these nations live gives them some opportunities to escape the burden of intellectual property law.[^71]
In my view, more developing nations should take advantage of that opportunity, but when they don't, then their laws should be respected.
And under the laws of these nations, this piracy is wrong.

Alternatively, we could try to excuse this piracy by noting that in any case, it does no harm to the industry.
The Chinese who get access to American CDs at 50 cents a copy are not people who would have bought those American CDs at $15 a copy.
So no one really has any less money than they otherwise would have had.[^72]

This is often true (though I have friends who have purchased many thousands of pirated DVDs who certainly have enough money to pay for the content they have taken), and it does mitigate to some degree the harm caused by such taking.
Extremists in this debate love to say, “You wouldn't go into Barnes & Noble and take a book off of the shelf without paying; why should it be any different with on-line music?” The difference is, of course, that when you take a book from Barnes & Noble, it has one less book to sell.
By contrast, when you take an MP3 from a computer network, there is not one less CD that can be sold.
The physics of piracy of the intangible are different from the physics of piracy of the tangible.

This argument is still very weak.
However, although copyright is a property right of a very special sort, it _is_ a property right.
Like all property rights, the copyright gives the owner the right to decide the terms under which content is shared.
If the copyright owner doesn't want to sell, she doesn't have to. There are exceptions: important statutory licenses that apply to copyrighted content regardless of the wish of the copyright owner.
Those licenses give people the right to “take” copyrighted content whether or not the copyright owner wants to sell.
But where the law does not give people the right to take content, it is wrong to take that content even if the wrong does no harm.
If we have a property system, and that system is properly balanced to the technology of a time, then it is wrong to take property without the permission of a property owner.
That is exactly what “property” means.

Finally, we could try to excuse this piracy with the argument that the piracy actually helps the copyright owner.
When the Chinese “steal” Windows, that makes the Chinese dependent on Microsoft.
Microsoft loses the value of the software that was taken.
But it gains users who are used to life in the Microsoft world.
Over time, as the nation grows more wealthy, more and more people will buy software rather than steal it. And hence over time, because that buying will benefit Microsoft, Microsoft benefits from the piracy.
If instead of pirating Microsoft Windows, the Chinese used the free GNU/Linux operating system, then these Chinese users would not eventually be buying Microsoft.
Without piracy, then, Microsoft would lose.

This argument, too, is somewhat true.
The addiction strategy is a good one.
Many businesses practice it. Some thrive because of it. Law students, for example, are given free access to the two largest legal databases.
The companies marketing both hope the students will become so used to their service that they will want to use it and not the other when they become lawyers (and must pay high subscription fees).

Still, the argument is not terribly persuasive.
We don't give the alcoholic a defense when he steals his first beer, merely because that will make it more likely that he will buy the next three.
Instead, we ordinarily allow businesses to decide for themselves when it is best to give their product away.
If Microsoft fears the competition of GNU/Linux, then Microsoft can give its product away, as it did, for example, with Internet Explorer to fight Netscape.
A property right means giving the property owner the right to say who gets access to what—at least ordinarily.
And if the law properly balances the rights of the copyright owner with the rights of access, then violating the law is still wrong.

Thus, while I understand the pull of these justifications for piracy, and I certainly see the motivation, in my view, in the end, these efforts at justifying commercial piracy simply don't cut it. This kind of piracy is rampant and just plain wrong.
It doesn't transform the content it steals; it doesn't transform the market it competes in. It merely gives someone access to something that the law says he should not have.
Nothing has changed to draw that law into doubt.
This form of piracy is flat out wrong.

But as the examples from the four chapters that introduced this part suggest, even if some piracy is plainly wrong, not all “piracy” is. Or at least, not all “piracy” is wrong if that term is understood in the way it is increasingly used today.
Many kinds of “piracy” are useful and productive, to produce either new content or new ways of doing business.
Neither our tradition nor any tradition has ever banned all “piracy” in that sense of the term.

This doesn't mean that there are no questions raised by the latest piracy concern, peer-to-peer file sharing.
But it does mean that we need to understand the harm in peer-to-peer sharing a bit more before we condemn it to the gallows with the charge of piracy.

For (1) like the original Hollywood, p2p sharing escapes an overly controlling industry; and (2) like the original recording industry, it simply exploits a new way to distribute content; but (3) unlike cable TV, no one is selling the content that is shared on p2p services.

These differences distinguish p2p sharing from true piracy.
They should push us to find a way to protect artists while enabling this sharing to survive.

### Piracy II

The key to the “piracy” that the law aims to quash is a use that “rob[s] the author of [his] profit.”[^73]
This means we must determine whether and how much p2p sharing harms before we know how strongly the law should seek to either prevent it or find an alternative to assure the author of his profit.

Peer-to-peer sharing was made famous by Napster.
But the inventors of the Napster technology had not made any major technological innovations.
Like every great advance in innovation on the Internet (and, arguably, off the Internet as well[^74]), Shawn Fanning and crew had simply put together components that had been developed independently.

The result was spontaneous combustion.
Launched in July 1999, Napster amassed over 10 million users within nine months.
After eighteen months, there were close to 80 million registered users of the system.[^75]
Courts quickly shut Napster down, but other services emerged to take its place.
(Kazaa is currently the most popular p2p service.
It boasts over 100 million members.)
These services' systems are different architecturally, though not very different in function: Each enables users to make content available to any number of other users.
With a p2p system, you can share your favorite songs with your best friend—or your 20,000 best friends.

According to a number of estimates, a huge proportion of Americans have tasted file-sharing technology.
A study by Ipsos-Insight in September 2002 estimated that 60 million Americans had downloaded music—28 percent of Americans older than 12.[^76]
A survey by the NPD group quoted in _The New York Times_ estimated that 43 million citizens used file-sharing networks to exchange content in May 2003.[^77]
The vast majority of these are not kids.
Whatever the actual figure, a massive quantity of content is being “taken” on these networks.
The ease and inexpensiveness of file-sharing networks have inspired millions to enjoy music in a way that they hadn't before.

Some of this enjoying involves copyright infringement.
Some of it does not.
And even among the part that is technically copyright infringement, calculating the actual harm to copyright owners is more complicated than one might think.
So consider—a bit more carefully than the polarized voices around this debate usually do—the kinds of sharing that file sharing enables, and the kinds of harm it entails.

File sharers share different kinds of content.
We can divide these different kinds into four types.

A. There are some who use sharing networks as substitutes for purchasing content.
Thus, when a new Madonna CD is released, rather than buying the CD, these users simply take it. We might quibble about whether everyone who takes it would actually have bought it if sharing didn't make it available for free.
Most probably wouldn't have, but clearly there are some who would.
The latter are the target of category A: users who download instead of purchasing.

B. There are some who use sharing networks to sample music before purchasing it. Thus, a friend sends another friend an MP3 of an artist he's not heard of. The other friend then buys CDs by that artist.
This is a kind of targeted advertising, quite likely to succeed.
If the friend recommending the album gains nothing from a bad recommendation, then one could expect that the recommendations will actually be quite good.
The net effect of this sharing could increase the quantity of music purchased.

C. There are many who use sharing networks to get access to copyrighted content that is no longer sold or that they would not have purchased because the transaction costs off the Net are too high.
This use of sharing networks is among the most rewarding for many.
Songs that were part of your childhood but have long vanished from the marketplace magically appear again on the network.
(One friend told me that when she discovered Napster, she spent a solid weekend “recalling” old songs.
She was astonished at the range and mix of content that was available.)
For content not sold, this is still technically a violation of copyright, though because the copyright owner is not selling the content anymore, the economic harm is zero—the same harm that occurs when I sell my collection of 1960s 45-rpm records to a local collector.

D. Finally, there are many who use sharing networks to get access to content that is not copyrighted or that the copyright owner wants to give away.

How do these different types of sharing balance out?

Let's start with some simple but important points.
From the perspective of the law, only type D sharing is clearly legal.
From the perspective of economics, only type A sharing is clearly harmful.[^78]
Type B sharing is illegal but plainly beneficial.
Type C sharing is illegal, yet good for society (since more exposure to music is good) and harmless to the artist (since the work is not otherwise available). So how sharing matters on balance is a hard question to answer—and certainly much more difficult than the current rhetoric around the issue suggests.

Whether on balance sharing is harmful depends importantly on how harmful type A sharing is. Just as Edison complained about Hollywood, composers complained about piano rolls, recording artists complained about radio, and broadcasters complained about cable TV, the music industry complains that type A sharing is a kind of “theft” that is “devastating” the industry.

While the numbers do suggest that sharing is harmful, how harmful is harder to reckon.
It has long been the recording industry's practice to blame technology for any drop in sales.
The history of cassette recording is a good example.
As a study by Cap Gemini Ernst & Young put it, “Rather than exploiting this new, popular technology, the labels fought it.”[^79]
The labels claimed that every album taped was an album unsold, and when record sales fell by 11.4 percent in 1981, the industry claimed that its point was proved.
Technology was the problem, and banning or regulating technology was the answer.

Yet soon thereafter, and before Congress was given an opportunity to enact regulation, MTV was launched, and the industry had a record turnaround.
“In the end,” Cap Gemini concludes, “the ‘crisis' … was not the fault of the tapers—who did not [stop after MTV came into being]—but had to a large extent resulted from stagnation in musical innovation at the major labels.”[^80]

But just because the industry was wrong before does not mean it is wrong today.
To evaluate the real threat that p2p sharing presents to the industry in particular, and society in general—or at least the society that inherits the tradition that gave us the film industry, the record industry, the radio industry, cable TV, and the VCR—the question is not simply whether type A sharing is harmful.
The question is also _how_ harmful type A sharing is, and how beneficial the other types of sharing are.

We start to answer this question by focusing on the net harm, from the standpoint of the industry as a whole, that sharing networks cause.
The “net harm” to the industry as a whole is the amount by which type A sharing exceeds type B. If the record companies sold more records through sampling than they lost through substitution, then sharing networks would actually benefit music companies on balance.
They would therefore have little _static_ reason to resist them.

Could that be true?
Could the industry as a whole be gaining because of file sharing?
Odd as that might sound, the data about CD sales actually suggest it might be close.

In 2002, the RIAA reported that CD sales had fallen by 8.9 percent, from 882 million to 803 million units; revenues fell 6.7 percent.[^81]
This confirms a trend over the past few years.
The RIAA blames Internet piracy for the trend, though there are many other causes that could account for this drop.
SoundScan, for example, reports a more than 20 percent drop in the number of CDs released since 1999\. That no doubt accounts for some of the decrease in sales.
Rising prices could account for at least some of the loss.
“From 1999 to 2001, the average price of a CD rose 7.2 percent, from $13.04 to $14.19.”[^82]
Competition from other forms of media could also account for some of the decline.
As Jane Black of _BusinessWeek_ notes, “The soundtrack to the film _High Fidelity_ has a list price of $18.98\. You could get the whole movie [on DVD] for $19.99.”[^83]

But let's assume the RIAA is right, and all of the decline in CD sales is because of Internet sharing.
Here's the rub: In the same period that the RIAA estimates that 803 million CDs were sold, the RIAA estimates that 2.1 billion CDs were downloaded for free.
Thus, although 2.6 times the total number of CDs sold were downloaded for free, sales revenue fell by just 6.7 percent.

There are too many different things happening at the same time to explain these numbers definitively, but one conclusion is unavoidable: The recording industry constantly asks, “What's the difference between downloading a song and stealing a CD?”—but their own numbers reveal the difference.
If I steal a CD, then there is one less CD to sell.
Every taking is a lost sale.
But on the basis of the numbers the RIAA provides, it is absolutely clear that the same is not true of downloads.
If every download were a lost sale—if every use of Kazaa “rob[bed] the author of [his] profit”—then the industry would have suffered a 100 percent drop in sales last year, not a 7 percent drop.
If 2.6 times the number of CDs sold were downloaded for free, and yet sales revenue dropped by just 6.7 percent, then there is a huge difference between “downloading a song and stealing a CD.”

These are the harms—alleged and perhaps exaggerated but, let's assume, real.
What of the benefits?
File sharing may impose costs on the recording industry.
What value does it produce in addition to these costs?

One benefit is type C sharing—making available content that is technically still under copyright but is no longer commercially available.
This is not a small category of content.
There are millions of tracks that are no longer commercially available.[^84]
And while it's conceivable that some of this content is not available because the artist producing the content doesn't want it to be made available, the vast majority of it is unavailable solely because the publisher or the distributor has decided it no longer makes economic sense _to the company_ to make it available.

In real space—long before the Internet—the market had a simple response to this problem: used book and record stores.
There are thousands of used book and used record stores in America today.[^85]
These stores buy content from owners, then sell the content they buy.
And under American copyright law, when they buy and sell this content, _even if the content is still under copyright_, the copyright owner doesn't get a dime.
Used book and record stores are commercial entities; their owners make money from the content they sell; but as with cable companies before statutory licensing, they don't have to pay the copyright owner for the content they sell.

Type C sharing, then, is very much like used book stores or used record stores.
It is different, of course, because the person making the content available isn't making money from making the content available.
It is also different, of course, because in real space, when I sell a record, I don't have it anymore, while in cyberspace, when someone shares my 1949 recording of Bernstein's “Two Love Songs,” I still have it. That difference would matter economically if the owner of the 1949 copyright were selling the record in competition to my sharing.
But we're talking about the class of content that is not currently commercially available.
The Internet is making it available, through cooperative sharing, without competing with the market.

It may well be, all things considered, that it would be better if the copyright owner got something from this trade.
But just because it may well be better, it doesn't follow that it would be good to ban used book stores.
Or put differently, if you think that type C sharing should be stopped, do you think that libraries and used book stores should be shut as well?

Finally, and perhaps most importantly, file-sharing networks enable type D sharing to occur—the sharing of content that copyright owners want to have shared or for which there is no continuing copyright.
This sharing clearly benefits authors and society.
Science fiction author Cory Doctorow, for example, released his first novel, _Down and Out in the Magic Kingdom_, both free on-line and in bookstores on the same day.
His (and his publisher's) thinking was that the on-line distribution would be a great advertisement for the “real” book.
People would read part on-line, and then decide whether they liked the book or not.
If they liked it, they would be more likely to buy it. Doctorow's content is type D content.
If sharing networks enable his work to be spread, then both he and society are better off.
(Actually, much better off: It is a great book!)

Likewise for work in the public domain: This sharing benefits society with no legal harm to authors at all.
If efforts to solve the problem of type A sharing destroy the opportunity for type D sharing, then we lose something important in order to protect type A content.

The point throughout is this: While the recording industry understandably says, “This is how much we've lost,” we must also ask, “How much has society gained from p2p sharing?
What are the efficiencies?
What is the content that otherwise would be unavailable?”

For unlike the piracy I described in the first section of this chapter, much of the “piracy” that file sharing enables is plainly legal and good.
And like the piracy I described in chapter 4, much of this piracy is motivated by a new way of spreading content caused by changes in the technology of distribution.
Thus, consistent with the tradition that gave us Hollywood, radio, the recording industry, and cable TV, the question we should be asking about file sharing is how best to preserve its benefits while minimizing (to the extent possible) the wrongful harm it causes artists.
The question is one of balance.
The law should seek that balance, and that balance will be found only with time.

“But isn't the war just a war against illegal sharing?
Isn't the target just what you call type A sharing?”

You would think.
And we should hope.
But so far, it is not.
The effect of the war purportedly on type A sharing alone has been felt far beyond that one class of sharing.
That much is obvious from the Napster case itself.
When Napster told the district court that it had developed a technology to block the transfer of 99.4 percent of identified infringing material, the district court told counsel for Napster 99.4 percent was not good enough.
Napster had to push the infringements “down to zero.”[^86]

If 99.4 percent is not good enough, then this is a war on file-sharing technologies, not a war on copyright infringement.
There is no way to assure that a p2p system is used 100 percent of the time in compliance with the law, any more than there is a way to assure that 100 percent of VCRs or 100 percent of Xerox machines or 100 percent of handguns are used in compliance with the law.
Zero tolerance means zero p2p.
The court's ruling means that we as a society must lose the benefits of p2p, even for the totally legal and beneficial uses they serve, simply to assure that there are zero copyright infringements caused by p2p.

Zero tolerance has not been our history.
It has not produced the content industry that we know today.
The history of American law has been a process of balance.
As new technologies changed the way content was distributed, the law adjusted, after some time, to the new technology.
In this adjustment, the law sought to ensure the legitimate rights of creators while protecting innovation.
Sometimes this has meant more rights for creators.
Sometimes less.

So, as we've seen, when “mechanical reproduction” threatened the interests of composers, Congress balanced the rights of composers against the interests of the recording industry.
It granted rights to composers, but also to the recording artists: Composers were to be paid, but at a price set by Congress.
But when radio started broadcasting the recordings made by these recording artists, and they complained to Congress that their “creative property” was not being respected (since the radio station did not have to pay them for the creativity it broadcast), Congress rejected their claim.
An indirect benefit was enough.

Cable TV followed the pattern of record albums.
When the courts rejected the claim that cable broadcasters had to pay for the content they rebroadcast, Congress responded by giving broadcasters a right to compensation, but at a level set by the law.
It likewise gave cable companies the right to the content, so long as they paid the statutory price.

This compromise, like the compromise affecting records and player pianos, served two important goals—indeed, the two central goals of any copyright legislation.
First, the law assured that new innovators would have the freedom to develop new ways to deliver content.
Second, the law assured that copyright holders would be paid for the content that was distributed.
One fear was that if Congress simply required cable TV to pay copyright holders whatever they demanded for their content, then copyright holders associated with broadcasters would use their power to stifle this new technology, cable.
But if Congress had permitted cable to use broadcasters' content for free, then it would have unfairly subsidized cable.
Thus Congress chose a path that would assure _compensation_ without giving the past (broadcasters) control over the future (cable).

In the same year that Congress struck this balance, two major producers and distributors of film content filed a lawsuit against another technology, the video tape recorder (VTR, or as we refer to them today, VCRs) that Sony had produced, the Betamax.
Disney's and Universal's claim against Sony was relatively simple: Sony produced a device, Disney and Universal claimed, that enabled consumers to engage in copyright infringement.
Because the device that Sony built had a “record” button, the device could be used to record copyrighted movies and shows.
Sony was therefore benefiting from the copyright infringement of its customers.
It should therefore, Disney and Universal claimed, be partially liable for that infringement.

There was something to Disney's and Universal's claim.
Sony did decide to design its machine to make it very simple to record television shows.
It could have built the machine to block or inhibit any direct copying from a television broadcast.
Or possibly, it could have built the machine to copy only if there were a special “copy me” signal on the line.
It was clear that there were many television shows that did not grant anyone permission to copy.
Indeed, if anyone had asked, no doubt the majority of shows would not have authorized copying.
And in the face of this obvious preference, Sony could have designed its system to minimize the opportunity for copyright infringement.
It did not, and for that, Disney and Universal wanted to hold it responsible for the architecture it chose.

MPAA president Jack Valenti became the studios' most vocal champion.
Valenti called VCRs “tapeworms.”
He warned, “When there are 20, 30, 40 million of these VCRs in the land, we will be invaded by millions of ‘tapeworms,' eating away at the very heart and essence of the most precious asset the copyright owner has, his copyright.”[^87] “One does not have to be trained in sophisticated marketing and creative judgment,” he told Congress, “to understand the devastation on the after-theater marketplace caused by the hundreds of millions of tapings that will adversely impact on the future of the creative community in this country.
It is simply a question of basic economics and plain common sense.”[^88]
Indeed, as surveys would later show, 45 percent of VCR owners had movie libraries of ten videos or more[^89]—a use the Court would later hold was not “fair.”
By “allowing VCR owners to copy freely by the means of an exemption from copyright infringement without creating a mechanism to compensate copyright owners,” Valenti testified, Congress would “take from the owners the very essence of their property: the exclusive right to control who may use their work, that is, who may copy it and thereby profit from its reproduction.”[^90]

It took eight years for this case to be resolved by the Supreme Court.
In the interim, the Ninth Circuit Court of Appeals, which includes Hollywood in its jurisdiction—leading Judge Alex Kozinski, who sits on that court, refers to it as the “Hollywood Circuit”—held that Sony would be liable for the copyright infringement made possible by its machines.
Under the Ninth Circuit's rule, this totally familiar technology—which Jack Valenti had called “the Boston Strangler of the American film industry” (worse yet, it was a _Japanese_ Boston Strangler of the American film industry)—was an illegal technology.[^91]

But the Supreme Court reversed the decision of the Ninth Circuit.
And in its reversal, the Court clearly articulated its understanding of when and whether courts should intervene in such disputes.
As the Court wrote,

> Sound policy, as well as history, supports our consistent deference to Congress when major technological innovations alter the market for copyrighted materials.
Congress has the constitutional authority and the institutional ability to accommodate fully the varied permutations of competing interests that are inevitably implicated by such new technology.[^92]

Congress was asked to respond to the Supreme Court's decision.
But as with the plea of recording artists about radio broadcasts, Congress ignored the request.
Congress was convinced that American film got enough, this “taking” notwithstanding.

If we put these cases together, a pattern is clear:

<div class="table-wrapper">
    <table>
        <tr>
            <th>Case</th>
            <th>Whose value was “pirated”</th>
            <th>Response of the courts</th>
            <th>Response of Congress</th>
        </tr>
        <tr>
            <th>Recordings</th>
            <td>Composers</td>
            <td>No protection</td>
            <td>Statutory License</td>
        </tr>
        <tr>
            <th>Radio</th>
            <td>Recording Artists</td>
            <td>N/A</td>
            <td>Nothing</td>
        </tr>
        <tr>
            <th>Cable TV</th>
            <td>Broadcasters</td>
            <td>No protection</td>
            <td>Statutory License</td>
        </tr>
        <tr>
            <th>VCR</th>
            <td>Film Creators</td>
            <td>No protection</td>
            <td>Nothing</td>
        </tr>
    </table>
</div>

Response of courts and Congress to new content distribution technologies.


In each case throughout our history, a new technology changed the way content was distributed.[^93]
In each case, throughout our history, that change meant that someone got a “free ride” on someone else's work.

In _none_ of these cases did either the courts or Congress eliminate all free riding.
In _none_ of these cases did the courts or Congress insist that the law should assure that the copyright holder get all the value that his copyright created.
In every case, the copyright owners complained of “piracy.”
In every case, Congress acted to recognize some of the legitimacy in the behavior of the “pirates.”
In each case, Congress allowed some new technology to benefit from content made before.
It balanced the interests at stake.

When you think across these examples, and the other examples that make up the first four chapters of this section, this balance makes sense.
Was Walt Disney a pirate?
Would doujinshi be better if creators had to ask permission?
Should tools that enable others to capture and spread images as a way to cultivate or criticize our culture be better regulated?
Is it really right that building a search engine should expose you to $15 million in damages?
Would it have been better if Edison had controlled film?
Should every cover band have to hire a lawyer to get permission to record a song?

We could answer yes to each of these questions, but our tradition has answered no. In our tradition, as the Supreme Court has stated, copyright “has never accorded the copyright owner complete control over all possible uses of his work.”[^94]
Instead, the particular uses that the law regulates have been defined by balancing the good that comes from granting an exclusive right against the burdens such an exclusive right creates.
And this balancing has historically been done _after_ a technology has matured, or settled into the mix of technologies that facilitate the distribution of content.

We should be doing the same thing today.
The technology of the Internet is changing quickly.
The way people connect to the Internet (wires vs. wireless) is changing very quickly.
No doubt the network should not become a tool for “stealing” from artists.
But neither should the law become a tool to entrench one particular way in which artists (or more accurately, distributors) get paid.
As I describe in some detail in the last chapter of this book, we should be securing income to artists while we allow the market to secure the most efficient way to promote and distribute content.
This will require changes in the law, at least in the interim.
These changes should be designed to balance the protection of the law against the strong public interest that innovation continue.

This is especially true when a new technology enables a vastly superior mode of distribution.
And this p2p has done.
P2p technologies can be ideally efficient in moving content across a widely diverse network.
Left to develop, they could make the network vastly more efficient.
Yet these “potential public benefits,” as John Schwartz writes in _The New York Times_, “could be delayed in the P2P fight.”[^95]

**Yet when anyone** begins to talk about “balance,” the copyright warriors raise a different argument.
“All this hand waving about balance and incentives,” they say, “misses a fundamental point.
Our content,” the warriors insist, “is our _property_.
Why should we wait for Congress to ‘rebalance' our property rights?
Do you have to wait before calling the police when your car has been stolen?
And why should Congress deliberate at all about the merits of this theft?
Do we ask whether the car thief had a good use for the car before we arrest him?”

“It is _our property_,” the warriors insist.
“And it should be protected just as any other property is protected.”


[^15]: *Bach* v. *Longman*, 98 Eng. Rep. 1274 (1777) (Mansfield).

[^16]: See Rochelle Dreyfuss, “Expressive Genericity: Trademarks as Language in the Pepsi Generation,” *Notre Dame Law Review* 65 (1990): 397.

[^17]: Lisa Bannon, “The Birds May Sing, but Campers Can't Unless They Pay Up,” *Wall Street Journal*, 21 August 1996, available at link #3; Jonathan Zittrain, “Calling Off the Copyright War: In Battle of Property vs. Free Speech, No One Wins,” *Boston Globe*, 24 November 2002.

[^18]: In *The Rise of the Creative Class* (New York: Basic Books, 2002), Richard Florida documents a shift in the nature of labor toward a labor of creativity.
	His work, however, doesn't directly address the legal conditions under which that creativity is enabled or stifled.
	I certainly agree with him about the importance and significance of this change, but I also believe the conditions under which it will be enabled are much more tenuous.

[^19]: Leonard Maltin, *Of Mice and Magic: A History of American Animated Cartoons* (New York: Penguin Books, 1987), 34-35.

[^20]: I am grateful to David Gerstein and his careful history, described at link #4. According to Dave Smith of the Disney Archives, Disney paid royalties to use the music for five songs in *Steamboat Willie*: “Steamboat Bill,”
	“The Simpleton” (Delille), “Mischief Makers” (Carbonara), “Joyful Hurry No. 1”
	(Baron), and “Gawky Rube” (Lakay). A sixth song, “The Turkey in the Straw,” was already in the public domain.
	Letter from David Smith to Harry Surden, 10 July 2003, on file with author.

[^21]: He was also a fan of the public domain.
	See Chris Sprigman, “The Mouse that Ate the Public Domain,” Findlaw, 5 March 2002, at link #5.

[^22]: Until 1976, copyright law granted an author the possibility of two terms: an initial term and a renewal term.
	I have calculated the “average” term by determining the weighted average of total registrations for any particular year, and the proportion renewing.
	Thus, if 100 copyrights are registered in year 1, and only 15 are renewed, and the renewal term is 28 years, then the average term is 32.2 years.
	For the renewal data and other relevant data, see the Web site associated with this book, available at link #6.

[^23]: For an excellent history, see Scott McCloud, *Reinventing Comics* (New York: Perennial, 2000).

[^24]: See Salil K. Mehra, “Copyright and Comics in Japan: Does Law Explain Why All the Comics My Kid Watches Are Japanese Imports?” *Rutgers Law Review* 55 (2002): 155, 182.
	“[T]here might be a collective economic rationality that would lead manga and anime artists to forgo bringing legal actions for infringement.
	One hypothesis is that all manga artists may be better off collectively if they set aside their individual self-interest and decide not to press their legal rights.
	This is essentially a prisoner's dilemma solved.”

[^25]: The term *intellectual property* is of relatively recent origin.
	See Siva Vaidhyanathan, *Copyrights and Copywrongs*, 11 (New York: New York University Press, 2001).
	See also Lawrence Lessig, *The Future of Ideas* (New York: Random House, 2001), 293 n. 26. The term accurately describes a set of “property” rights—copyright, patents, trademark, and trade-secret—but the nature of those rights is very different.

[^26]: Reese V. Jenkins, *Images and Enterprise* (Baltimore: Johns Hopkins University Press, 1975), 112.

[^27]: Brian Coe, *The Birth of Photography* (New York: Taplinger Publishing, 1977), 53.

[^28]: Jenkins, 177.

[^29]: Based on a chart in Jenkins, p. 178.

[^30]: Coe, 58.

[^31]: For illustrative cases, see, for example, *Pavesich* v. *N.E. Life Ins. Co*., 50 S.E. 68 (Ga. 1905); *Foster-Milburn Co*. v. *Chinn*, 123090 S.W. 364, 366 (Ky. 1909); *Corliss* v. *Walker*, 64 F. 280 (Mass. Dist. Ct. 1894).

[^32]: Samuel D. Warren and Louis D. Brandeis, “The Right to Privacy,” *Harvard Law Review* 4 (1890): 193.

[^33]: See Melville B. Nimmer, “The Right of Publicity,” *Law and Contemporary Problems* 19 (1954): 203; William L. Prosser, “Privacy,” *California Law Review* 48 (1960) 398-407; *White* v. *Samsung Electronics America, Inc*., 971 F. 2d 1395 (9th Cir. 1992), cert. denied, 508 U.S. 951 (1993).

[^34]: H. Edward Goldberg, “Essential Presentation Tools: Hardware and Software You Need to Create Digital Multimedia Presentations,” cadalyst, 1 February 2002, available at link #7.

[^35]: Judith Van Evra, *Television and Child Development* (Hillsdale, N.J.: Lawrence Erlbaum Associates, 1990); “Findings on Family and TV Study,” *Denver Post*, 25 May 1997, B6.

[^36]: Interview with Elizabeth Daley and Stephanie Barish, 13 December 2002.

[^37]: See Scott Steinberg, “Crichton Gets Medieval on PCs,” E!online, 4 November 2000, available at link #8; “Timeline,” 22 November 2000, available at link #9.

[^38]: Interview with Daley and Barish.

[^39]: Ibid.

[^40]: See, for example, Alexis de Tocqueville, *Democracy in America*, bk. 1, trans. Henry Reeve (New York: Bantam Books, 2000), ch. 16.

[^41]: Bruce Ackerman and James Fishkin, “Deliberation Day,” *Journal of Political Philosophy* 10 (2) (2002): 129\.

[^42]: Cass Sunstein, *Republic.com* (Princeton: Princeton University Press, 2001), 65-80, 175, 182, 183, 192.

[^43]: Noah Shachtman, “With Incessant Postings, a Pundit Stirs the Pot,” *New York Times*, 16 January 2003, G5.

[^44]: Telephone interview with David Winer, 16 April 2003.

[^45]: John Schwartz, “Loss of the Shuttle: The Internet; A Wealth of Information Online,” *New York Times*, 2 February 2003, A28; Staci D. Kramer, “Shuttle Disaster Coverage Mixed, but Strong Overall,” Online Journalism Review, 2 February 2003, available at link #10.

[^46]: See Michael Falcone, “Does an Editor's Pencil Ruin a Web Log?” *New York Times*, 29 September 2003, C4.
	(“Not all news organizations have been as accepting of employees who blog.
	Kevin Sites, a CNN correspondent in Iraq who started a blog about his reporting of the war on March 9, stopped posting 12 days later at his bosses' request.
	Last year Steve Olafson, a *Houston Chronicle* reporter, was fired for keeping a personal Web log, published  under a pseudonym, that dealt with some of the issues and people he was covering.”)

[^47]: See, for example, Edward Felten and Andrew Appel, “Technological Access Control Interferes with Noninfringing Scholarship,” *Communications of the Association for Computer Machinery* 43 (2000): 9.

[^48]: Tim Goral, “Recording Industry Goes After Campus P-2-P Networks: Suit Alleges $97.8 Billion in Damages,” *Professional Media Group LCC* 6 (2003): 5, available at 2003 WL 55179443.

[^49]: Occupational Employment Survey, U.S. Dept. of Labor (2001) (27-2042—Musicians and Singers). See also National Endowment for the Arts, *More Than One in a Blue Moon* (2000).

[^50]: Douglas Lichtman makes a related point in “KaZaA and Punishment,” *Wall Street Journal*, 10 September 2003, A24.

[^51]: I am grateful to Peter DiMauro for pointing me to this extraordinary history. 
	See also Siva Vaidhyanathan, *Copyrights and Copywrongs*, 87-93, which details Edison's “adventures” with copyright and patent.

[^52]: J. A. Aberdeen, *Hollywood Renegades: The Society of Independent Motion Picture Producers* (Cobblestone Entertainment, 2000) and expanded texts posted at “The Edison Movie Monopoly: The Motion Picture Patents Company vs. the Independent Outlaws,” available at link #11. For a discussion of the economic motive behind both these limits and the limits imposed by Victor on phonographs, see Randal C. Picker, “From Edison to the Broadcast Flag: Mechanisms of Consent and Refusal and the Propertization of Copyright” (September 2002), University of Chicago Law School, James M. Olin Program in Law and Economics, Working Paper No. 159.

[^53]: Marc Wanamaker, “The First Studios,” *The Silents Majority*, archived at link #12.

[^54]: To Amend and Consolidate the Acts Respecting Copyright: Hearings on S. 6330 and H.R. 19853 Before the (Joint) Committees on Patents, 59th Cong. 59, 1st sess. (1906) (statement of Senator Alfred B. Kittredge, of South Dakota, chairman), reprinted in *Legislative History of the 1909 Copyright Act*, E. Fulton Brylawski and Abe Goldman, eds. (South Hackensack, N.J.: Rothman Reprints, 1976).

[^55]: To Amend and Consolidate the Acts Respecting Copyright, 223 (statement of Nathan Burkan, attorney for the Music Publishers Association).

[^56]: To Amend and Consolidate the Acts Respecting Copyright, 226 (statement of Nathan Burkan, attorney for the Music Publishers Association).

[^57]: To Amend and Consolidate the Acts Respecting Copyright, 23 (statement of John Philip Sousa, composer).

[^58]: To Amend and Consolidate the Acts Respecting Copyright, 283-84 (statement of Albert Walker, representative of the Auto-Music Perforating Company of New York).

[^59]: To Amend and Consolidate the Acts Respecting Copyright, 376 (prepared memorandum of Philip Mauro, general patent counsel of the American Graphophone Company Association).

[^60]: Copyright Law Revision: Hearings on S. 2499, S. 2900, H.R. 243, and H.R. 11794 Before the (Joint) Committee on Patents, 60th Cong., 1st sess., 217 (1908) (statement of Senator Reed Smoot, chairman), reprinted in *Legislative History of the 1909 Copyright Act*, E. Fulton Brylawski and Abe Goldman, eds. (South Hackensack, N.J.: Rothman Reprints, 1976).

[^61]: Copyright Law Revision: Report to Accompany H.R. 2512, House Committee on the Judiciary, 90th Cong., 1st sess., House Document no. 83, 66 (8 March 1967). I am grateful to Glenn Brown for drawing my attention to this report.

[^62]: See 17 *United States Code*, sections 106 and 110.
	At the beginning, record companies printed “Not Licensed for Radio Broadcast” and other messages purporting to restrict the ability to play a record on a radio station.
	Judge Learned Hand rejected the argument that a warning attached to a record might restrict the rights of the radio station.
	See *RCA Manufacturing Co*. v. *Whiteman*, 114 F. 2d 86 (2nd Cir. 1940).
	See also Randal C. Picker, “From Edison to the Broadcast Flag: Mechanisms of Consent and Refusal and the Propertization of Copyright,” *University of Chicago Law Review* 70 (2003): 281.

[^63]: Copyright Law Revision—CATV: Hearing on S. 1006 Before the Subcommittee on Patents, Trademarks, and Copyrights of the Senate Committee on the Judiciary, 89th Cong., 2nd sess., 78 (1966) (statement of Rosel H. Hyde, chairman of the Federal Communications Commission).

[^64]: Copyright Law Revision—CATV, 116 (statement of Douglas A. Anello, general counsel of the National Association of Broadcasters).

[^65]: Copyright Law Revision—CATV, 126 (statement of Ernest W. Jennes, general counsel of the Association of Maximum Service Telecasters, Inc.).

[^66]: Copyright Law Revision—CATV, 169 (joint statement of Arthur B. Krim, president of United Artists Corp., and John Sinn, president of United Artists Television, Inc.).

[^67]: Copyright Law Revision—CATV, 209 (statement of Charlton Heston, president of the Screen Actors Guild).

[^68]: Copyright Law Revision—CATV, 216 (statement of Edwin M. Zimmerman, acting assistant attorney general).

[^69]: See, for example, National Music Publisher's Association, *The Engine of Free Expression: Copyright on the Internet—The Myth of Free Information*, available  at link #13.
	“The threat of piracy—the use of someone else's creative work without permission or compensation—has grown with the Internet.”

[^70]: See IFPI (International Federation of the Phonographic Industry), *The Recording Industry Commercial Piracy Report 2003*, July 2003, available at link #14. See also Ben Hunt, “Companies Warned on Music Piracy Risk,” *Financial Times*, 14 February 2003, 11.

[^71]: See Peter Drahos with John Braithwaite, *Information Feudalism: Who Owns the Knowledge Economy?* (New York: The New Press, 2003), 10-13, 209.
	The Trade-Related Aspects of Intellectual Property Rights (TRIPS) agreement obligates member nations to create administrative and enforcement mechanisms for intellectual property rights, a costly proposition for developing countries.
	Additionally, patent rights may lead to higher prices for staple industries such as agriculture.
	Critics of TRIPS question the disparity between burdens imposed upon developing countries and benefits conferred to industrialized nations.
	TRIPS does permit governments to use patents for public, noncommercial uses without first obtaining the patent holder's permission.
	Developing nations may be able to use this to gain the benefits of foreign patents at lower prices.
	This is a promising strategy for developing nations within the TRIPS framework.

[^72]: For an analysis of the economic impact of copying technology, see Stan Liebowitz, *Rethinking the Network Economy* (New York: Amacom, 2002), 144-90.
	“In some instances … the impact of piracy on the copyright holder's ability to appropriate the value of the work will be negligible.
	One obvious instance is the case where the individual engaging in pirating would not have purchased an original even if pirating were not an option.”
	Ibid., 149.

[^73]: *Bach* v. *Longman*, 98 Eng.
	Rep. 1274 (1777).

[^74]: See Clayton M. Christensen, *The Innovator's Dilemma: The Revolutionary National Bestseller That Changed the Way We Do Business* (New York: HarperBusiness, 2000). Professor Christensen examines why companies that give rise to and dominate a product area are frequently unable to come up with the most creative, paradigm-shifting uses for their own products.
	This job usually falls to outside innovators, who reassemble existing technology in inventive ways.
	For a discussion of Christensen's ideas, see Lawrence Lessig, *Future*, 89-92, 139.

[^75]: See Carolyn Lochhead, “Silicon Valley Dream, Hollywood Nightmare,” *San Francisco Chronicle*, 24 September 2002, A1; “Rock 'n' Roll Suicide,” *New Scientist*, 6 July 2002, 42; Benny Evangelista, “Napster Names CEO, Secures New Financing,” *San Francisco Chronicle*, 23 May 2003, C1; “Napster's Wake-Up Call,” *Economist*, 24 June 2000, 23; John Naughton, “Hollywood at War with the Internet” (London) *Times*, 26 July 2002, 18.

[^76]: See Ipsos-Insight, *TEMPO: Keeping Pace with Online Music Distribution* (September  2002), reporting that 28 percent of Americans aged twelve and older have downloaded music off of the Internet and 30 percent have listened to digital music files stored on their computers.

[^77]: Amy Harmon, “Industry Offers a Carrot in Online Music Fight,” *New York Times*, 6 June 2003, A1.

[^78]: See Liebowitz, *Rethinking the Network Economy*,148-49.

[^79]: See Cap Gemini Ernst &amp; Young, *Technology Evolution and the Music Industry's Business Model Crisis* (2003), 3.
	This report describes the music industry's effort to stigmatize the budding practice of cassette taping in the 1970s, including an advertising campaign featuring a cassette-shape skull and the caption “Home taping is killing music.”

    At the time digital audio tape became a threat, the Office of Technical Assessment conducted a survey of consumer behavior.
	In 1988, 40 percent of consumers older than ten had taped music to a cassette format.
	U.S. Congress, Office of Technology Assessment, *Copyright and Home Copying: Technology Challenges the Law*, OTA-CIT-422 (Washington, D.C.: U.S. Government Printing Office, October 1989), 145-56.

[^80]: U.S. Congress, *Copyright and Home Copying*, 4.

[^81]: See Recording Industry Association of America, *2002 Yearend Statistics*, available at link #15. A later report indicates even greater losses.
	See Recording Industry Association of America, *Some Facts About Music Piracy*, 25 June 2003, available at link #16: “In the past four years, unit shipments of recorded music have fallen by 26 percent from 1.16 billion units in 1999 to 860 million units in 2002 in the United States (based on units shipped). In terms of sales, revenues are down 14 percent, from $14.6 billion in 1999 to $12.6 billion last year (based on U.S. dollar value of shipments). The music industry worldwide has gone from a $39 billion industry in 2000 down to a $32 billion industry in 2002 (based on U.S. dollar value of shipments).”

[^82]: Jane Black, “Big Music's Broken Record,”
	BusinessWeek online, 13 February 2003, available at link #17.

[^83]: Ibid.

[^84]: By one estimate, 75 percent of the music released by the major labels is no longer in print.
	See Online Entertainment and Copyright Law—Coming Soon to a Digital Device Near You: Hearing Before the Senate Committee on the Judiciary, 107th Cong., 1st sess. (3 April 2001) (prepared statement of the Future of Music Coalition), available at link #18.

[^85]: While there are not good estimates of the number of used record stores in existence, in 2002, there were 7,198 used book dealers in the United States, an increase of 20 percent since 1993. See Book Hunter Press, *The Quiet Revolution: The Expansion of the Used Book Market* (2002), available at link #19. Used records accounted for $260 million in sales in 2002.
	See National Association of Recording Merchandisers, “2002 Annual Survey Results,” available at link #20.

[^86]: See Transcript of Proceedings, In Re: Napster Copyright Litigation at 34-35 (N.D. Cal., 11 July 2001), nos.
	MDL-00-1369 MHP, C 99-5183 MHP, available at link #21. For an account of the litigation and its toll on Napster, see Joseph Menn, *All the Rave: The Rise and Fall of Shawn Fanning's Napster* (New York: Crown Business, 2003), 269-82.

[^87]: Copyright Infringements (Audio and Video Recorders): Hearing on S. 1758 Before the Senate Committee on the Judiciary, 97th Cong., 1st and 2nd sess., 459 (1982) (testimony of Jack Valenti, president, Motion Picture Association of America, Inc.).

[^88]: Copyright Infringements (Audio and Video Recorders), 475\.

[^89]: *Universal City Studios, Inc*. v. *Sony Corp. of America*, 480 F. Supp. 429, 438 (C.D. Cal., 1979).

[^90]: Copyright Infringements (Audio and Video Recorders), 485 (testimony of Jack Valenti).

[^91]: *Universal City Studios, Inc*. v. *Sony Corp. of America*, 659 F. 2d 963 (9th Cir. 1981).

[^92]: *Sony Corp. of America* v. *Universal City Studios, Inc*., 464 U.S. 417, 431 (1984).

[^93]: These are the most important instances in our history, but there are other cases as well.
	The technology of digital audio tape (DAT), for example, was regulated by Congress to minimize the risk of piracy.
	The remedy Congress imposed did burden DAT producers, by taxing tape sales and controlling the technology of DAT.
	See Audio Home Recording Act of 1992 (Title 17 of the *United States Code*), Pub. L. No. 102-563, 106 Stat. 4237, codified at 17 U.S.C. §1001.
	Again, however, this regulation did not eliminate the opportunity for free riding in the sense I've described.
	See Lessig, *Future*, 71. See also Picker, “From Edison to the Broadcast Flag,” *University of Chicago Law Review* 70 (2003): 293-96.

[^94]: *Sony Corp. of America* v. *Universal City Studios, Inc*., 464 U.S. 417, 432 (1984).

[^95]: John Schwartz, “New Economy: The Attack on Peer-to-Peer Software Echoes Past Efforts,” *New York Times*, 22 September 2003, C3.
